/*
 * *****************************************************************
 * *                                                               *
 * *    Copyright Compaq Computer Corporation, 2001                *
 * *                                                               *
 * *   The software contained on this media  is  proprietary  to   *
 * *   and  embodies  the  confidential  technology  of  Compaq    *
 * *   Computer Corporation.  Possession, use,  duplication  or    *
 * *   dissemination of the software and media is authorized only  *
 * *   pursuant to a valid written license from Compaq Computer    *
 * *   Corporation.                                                *
 * *                                                               *
 * *   RESTRICTED RIGHTS LEGEND   Use, duplication, or disclosure  *
 * *   by the U.S. Government is subject to restrictions  as  set  *
 * *   forth in Subparagraph (c)(1)(ii)  of  DFARS  252.227-7013,  *
 * *   or  in  FAR 52.227-19, as applicable.                       *
 * *                                                               *
 * *****************************************************************
 */
/* 
 * HISTORY
 */
#pragma ident "@(#)$RCSfile: lockinfo.c,v $ $Revision: 1.1.1283.1 $ (DEC) $Date: 2001/09/11 18:38:53 $"

#include <sys/types.h>
#include <sys/systm.h>
#include <kern/lock.h>
#include <machine/cpu.h>
#include <unix_locks.h>
#include <net/net_globals.h>
#include <sys/lock_probe.h>
#ifdef	ZENO
#include <tnc/tncdefs.h>
#include <tnc/tnc_synch.h>
#endif	/* ZENO */
#if 0
#include "rt_sem.h"
#endif
#include "rt_ipc.h"
#include "rt_csem.h"
#include "packetfilter.h"
#include "gwscreen.h"
#include "pty.h"
#include "rpty.h"
#include "dli.h"
#include "dlb.h"
#include  "dlpi.h"
#include "dec_audit.h"
//#include "xza.h"
#include "aha.h"
#include "pza.h"
//#include "tza.h"
#include "isp.h"
#include "psiop.h"
#include "cdfs.h"
#include "nfs.h"
#include "ffm_fs.h"
#include "streams.h"
#include "strifnet.h"
#if	__alpha
#include "xcr.h"
//#include "ci.h"
//#include "uq.h"
#endif	/* __alpha */
#include "ldtty.h"
#include "pci.h"
#include "msfs.h"
#include "drd.h"
#include "cnx.h"
#include "kch.h"
#include "dlm.h"
#include "ccomsub.h"
#include "mcnet.h"
#include "icsnet.h"
#include "rm.h"
#include "rmvm.h"
#include "ics_hl.h"
#include "ics_ll_tcp.h"
#include "ics_ll_mct.h"
#include "procfs.h"
#include "lsm.h"
#include "scsi.h"
#include "xtiso.h"
#include "ppp.h"
#include "atm.h"
#include "atmip.h"
#include "lane.h"
#include "atmifmp.h"
#include "pat.h"
#include "uni3x.h"
#include "atmsig2.h"
#include "atmilmi3x.h"
#include "atmuni.h"
#include "pwrmgr_enabled.h"
#include "uipc.h"
#include "usb.h"
#include "cms.h"
#include "pnvram.h"
#include "clua.h"
#include "autofs.h"
#include "crypto.h"
#include "ipsec.h"
/*
 * only include Eisa nvram on alpha 
 */
#ifdef __alpha
#include "envram.h"
#else
#define NENVRAM 0
#endif


#if MACH_SLOCKS
#define SCC(xxx) xxx
#else
#define SCC(xxx)
#endif

#if UNIX_LOCKS
#define UCC(xxx) xxx
#else
#define UCC(xxx)
#endif

#if NETSYNC_LOCK
#define NCC(xxx) xxx
#else
#define NCC(xxx)
#endif

#define LI(name, extlip, minspl, flags) { \
	extern struct lockinfo *extlip; \
	lip->li_name = name; \
	lip->li_count = 0; \
	lip->li_flgspl = (minspl) | (flags); \
	extlip = lip++; \
}
#define SLI(a,b,c,d) SCC(LI(a,b,c,d))
#define ULI(a,b,c,d) UCC(LI(a,b,c,d))
#define NLI(a,b,c,d) NCC(LI(a,b,c,d))

#define LI_DISABLE_HIERARCHY_CHECKING(p) { \
	extern struct lockinfo *p; \
	(p)->li_flgspl &= ~LI_DOHIER; \
}
#define SLI_DISABLE_HIERARCHY_CHECKING(p) SCC(LI_DISABLE_HIERARCHY_CHECKING(p))
#define ULI_DISABLE_HIERARCHY_CHECKING(p) UCC(LI_DISABLE_HIERARCHY_CHECKING(p))
#define NLI_DISABLE_HIERARCHY_CHECKING(p) NCC(LI_DISABLE_HIERARCHY_CHECKING(p))

#define DEFAULT (LI_VALID | LI_DOHIER) /* default lockinfo flags */
#define	RWS	(LI_RWS | LI_VALID | LI_DOHIER) /*RWS default lockinfo flags */
#define PROBE   (LI_VALID | LI_PROBE)  /* Flags set probing */
#define ORDERED (DEFAULT | LI_ORDERED)
#define ORDNEXT (DEFAULT | LI_ORDNEXT)

#define ULI_NOCHECK(name, extlip) { \
	ULI(name, extlip, SPLNONE, DEFAULT); \
	ULI_DISABLE_HIERARCHY_CHECKING(extlip); \
}

#ifdef LOCK_PROBE
int probe_smp = 1;	/* 0 == disabled at PROBE_START/END macro */
#define ULI_PROBE(name, extlip) { \
	ULI(name, extlip, SPLNONE, PROBE); \
}
#else
#define ULI_PROBE(name, extlip)
#endif /* LOCK_PROBE */

#ifdef	TNC
#define TNCLI(lockdata) { \
	EXTERN_LOCKDATA_T(lockdata); \
	lip->li_name = (lockdata).lock_name; \
	lip->li_count = 0; \
	lip->li_flgspl = ((lockdata).lock_ipl) | DEFAULT; \
	(lockdata).lock_info = lip++; \
}
#endif	/* TNC */

extern int lockinfo_count;
extern struct lockinfo *lockinfo_table;
extern struct lockstats **lockstats_table;

/*
 * The following function contains lockinfo specs for initializing the
 * complex and simple lock data structures associated with lock debugging
 * and statistics.  The order of the LI() macro invocations determines the
 * relative locking hierarchy positions between classes of locks, with specs
 * nearer the beginning of the function referring to higher (or outermost)
 * locks and specs nearer the end of the function referring to lower (or
 * innermost) locks.  To add a new lockinfo spec, follow these steps:
 *
 *	1) Determine where the class of locks fits in below, and add a new
 *		LI() line in the function below specifying the class name,
 *		the name of an external lockinfo structure pointer, the
 *		minimum required spl level for lock acquisition, and the
 *		default trace flag constant.  The suggested class naming
 *		convention is to use the name of the global lock instance
 *		for single-lock classes or <structure_name>.<field_name>
 *		for classes of locks which are fields in other structures.
 *		If the associated lock instances are conditionally compiled,
 *		use the SLI(), ULI(), or NLI() macro in place of LI() as
 *		appropriate.
 *
 *	2) Add the global (struct lockinfo *) variable to the source file
 *		related to the locking class.  Use conditionally compiled
 *		declarations (decl_simple_lock_info/udecl_simple_lock_info)
 *		if the associated lock instances are conditionally compiled.
 *
 *	3) Replace the associated lock_init() or simple_lock_init() calls
 *		with lock_setup() or simple_lock_setup() calls naming the
 *		global (struct lockinfo *) variable as the 2nd argument.
 *
 *	4) If the lock class is a field of a data structure which is
 *		dynamically allocated and freed, add a complementary call
 *		to lock_terminate() or simple_lock_terminate() just before
 *		the data structure is freed.
 */

int 
lockinfo_bootstrap(struct lockinfo *lip_start)
{
	register struct lockinfo *lip;
	register struct lockstats *lsp;
	register int i;

	lip = lip_start;
	lip->li_name = "unknown_simple_lock";
	lip->li_count = 0;
	lip->li_flgspl = 0;
	lip++;
	lip->li_name = "unknown_complex_lock";
	lip->li_count = 0;
	lip->li_flgspl = 0;
	lip++;

	/*********************************************/
	/* start of lockinfo specs for complex locks */
	/*********************************************/
	LI("primary_assign_lock", primary_assign_lockinfo, SPLNONE, DEFAULT);
	LI("class_dbase_lock", class_dbase_lockinfo, SPLNONE, DEFAULT);
	LI("lockdev_lock", lockdev_lockinfo, SPLNONE, DEFAULT);
	LI("sys_exitp_lock", sys_exitp_lockinfo, SPLNONE, DEFAULT);
	ULI("nfs_export_lock", nfs_export_lockinfo, SPLNONE, DEFAULT);
	LI("lock_for_exported", lockinfo_for_exported, SPLNONE, DEFAULT);
        ULI("rfs_read_seq_lock", rfs_read_seq_lockinfo, SPLNONE, DEFAULT);
	LI("mount.m_unmount_lock", unmount_lockinfo, SPLNONE, DEFAULT);
	LI("fdfs_lock", fdfs_lockinfo, SPLNONE, DEFAULT);
	LI("cfg_subsys_lock", cfg_subsys_lockinfo, SPLNONE, ORDERED);
	LI("callbk_list_lock", callbk_list_lockinfo, SPLNONE, DEFAULT);
	LI("sysdev_lock", sysdev_lockinfo, SPLNONE, DEFAULT);
	LI("lk_audit", lk_audit_info, SPLNONE, DEFAULT);
#if ATM
#if UNI3X /* New ATM Signaling */
	ULI("atmsig_softc.timer_lock", atmsig_timer_lock_i, SPLNONE, DEFAULT);
#endif /* UNI3X */
#endif /* ATM */
	LI("inode.i_io_lock", i_io_lockinfo, SPLNONE, ORDERED);
	LI_DISABLE_HIERARCHY_CHECKING(i_io_lockinfo);
	LI("nfs_daemon_lock", nfs_daemon_lockinfo, SPLNONE, DEFAULT);

#if PROCFS > 0
	LI("procnode.prc_ioctl_lock", procnode_ioctl_lockinfo,SPLNONE,ORDERED);
	LI("procfs_mount_lock", procfs_mount_lockinfo, SPLNONE, DEFAULT);
#endif
	LI("semidq_lock", semidq_lockinfo, SPLNONE, DEFAULT);
	LI("msgidq_lock", msgidq_lockinfo, SPLNONE, DEFAULT);
	LI("utask.uu_addr_lock", u_addr_lockinfo, SPLNONE, DEFAULT);
#if ATM
#if ATMIP
        NLI("request_q_complex_lock", request_q_complex_lock_info, SPLNONE, DEFAULT);
#endif
#endif

#ifdef TNC_CFE
	/*
	 * For now, these locks are NOCHECK.
	 */
	ULI("cfs_recovery_lock", fo_recovery_lockinfo, SPLNONE, ORDERED);
	ULI_DISABLE_HIERARCHY_CHECKING(fo_recovery_lockinfo);
	ULI("svrcfstok.sct_rwlock", sct_rw_lockinfo, SPLNONE, ORDERED);
	ULI_DISABLE_HIERARCHY_CHECKING(sct_rw_lockinfo);
	ULI("cnode.c_rwlock", c_rw_lockinfo, SPLNONE, ORDERED);
	ULI_DISABLE_HIERARCHY_CHECKING(c_rw_lockinfo);

	ULI("cfs_unlksys_lock", cfs_unlksys_list_lockinfo, SPLNONE, DEFAULT);
#endif /* TNC_CFE */

	/* "PSM_set.lock" must be above "vm_umap.vm_lock" */
	LI("PSM_set.lock", psm_set_lockinfo, SPLNONE, DEFAULT);

#if MSFS > 0
	/***********************************************
	 * AdvFS Complex (sleep) locks in hierarchy
	 ***********************************************/
	LI("DmnTblLock", ADVDmnTblLock_info, SPLNONE, DEFAULT );
	LI("InitLock", ADVInitLock_info, SPLNONE, DEFAULT );
        LI("fsContext.kdmLock",ADVfsContext_kdmLock_lockinfo, SPLNONE, DEFAULT);
	LI("fsContext.file_lock", ADVfsContext_file_lock_info, SPLNONE,
           ORDERED | ORDNEXT );
    /* DO NOT PUT ANY LOCK BETWEEN fsContext.file_lock AND vm_umap.vm_lock
     * BECAUSE OF THE ORDNEXT FLAG ON THE FILE_LOCK!!  THESE MUST BE AT THE
     * SAME HIERARCHY LEVEL.  OR ELSE.
     */
#endif
	LI("vm_umap.vm_lock", u_map_lockinfo, SPLNONE, DEFAULT);

	/*
	 * Lock classes below "vm_umap.vm_lock" must not be used for
	 * locks held across calls to copyin(), copyout(), or other
	 * user-space access routines because page fault handling
	 * requires the locking of user-space vm_map structures.
	 */

#ifdef TNC_CFE
	ULI("blkrsrv_dmn_lock", bd_dmn_lkdata, SPLNONE, DEFAULT);
	ULI_DISABLE_HIERARCHY_CHECKING(bd_dmn_lkdata);
#endif

#if CMS > 0
        LI("db_rwlock_lock", db_rwlock_lockinfo, SPLNONE, ORDERED);
#endif /* CMS */

#ifdef	TNC_CFE

	TNCLI(clock_tcb_lkdata);	/* PLBASE(0), 0 */

#ifdef OLD_SERVER_TOKEN_LOCKING
	TNCLI(sct_tcblock_lkdata);
#endif
	TNCLI(cdta_statelock_lkdata);

#endif	/* TNC_CFE */

	LI("rnode.r_rwlock", rnode_rw_lockinfo, SPLNONE, ORDERED);


#ifdef TNC_CFE
	ULI("exsvr_lockinfo", exsvr_lockinfo, SPLNONE, DEFAULT);
#endif

#if MSFS > 0
	/***********************************************
	 * AdvFS Complex (sleep) locks in hierarchy - cont
	 ***********************************************/
        LI("domainT.rmvolTruncLk", ADVdomainT_rmvolTruncLk_info, SPLNONE, DEFAULT);
        LI("bfAccessT.trunc_xfer_lk", ADVbfAccessT_trunc_xfer_lk_info, SPLNONE, DEFAULT );
	LI("bfAccessT.clu_clonextnt_lk", ADVbfAccessT_clu_clonextnt_lk_info, SPLNONE, DEFAULT );
	LI("bsInMemXtntT.migTruncLk", ADVbsInMemXtntT_migTruncLk_info, SPLNONE, ORDERED );
	LI("ddlActiveLk", ADVvdT_ddlActiveLk_info, SPLNONE, DEFAULT );
        LI("BfSetTblLock", ADVBfSetTblLock_info, SPLNONE, DEFAULT );
	LI("quotaInfoT_qiLock", ADVquotaInfoT_qiLock, SPLNONE, DEFAULT );
	LI("bfSetT.fragLock", ADVbfSetT_fragLock_info, SPLNONE, DEFAULT );
	LI("bfSetT.dirLock", ADVbfSetT_dirLock_info, SPLNONE, DEFAULT );
/*	LI("bfAccessT.cow_lk", ADVbfAccessT_cow_lk_info, SPLNONE, DEFAULT );*/
	LI("Clone.bsInMemXtntT.migTruncLk", ADVClonebsInMemXtntT_migTruncLk_info, SPLNONE, ORDERED | ORDNEXT);
        /* DO NOT PUT ANY LOCK BETWEEN Clone.bsInMemXtntT.migTruncLk AND 
         * bfAccessT.mcellList_lk BECAUSE OF THE ORDNEXT FLAG ON THE 
         * Clone.bsInMemXtntT.migTruncLk!! THESE MUST BE AT THE SAME 
         * HIERARCHY LEVEL.  OR ELSE.
         */
	LI("bfAccessT.mcellList_lk", ADVbfAccessT_mcellList_lk_info, SPLNONE, ORDERED );
	/* The original file's xtntMap_lk is locked before the clone's. */
	LI("bfAccessT.xtntMap_lk", ADVbfAccessT_xtntMap_lk_info, SPLNONE, ORDERED );
	LI("FilesetLock", ADVFilesetLock_lockinfo, SPLNONE, DEFAULT );
/*	LI("dQuot.dqLock", ADVdQuot_dqLock_info, SPLNONE, DEFAULT ); */
	LI("vdT.mcell_lk", ADVvdT_mcell_lk_info, SPLNONE, DEFAULT );
	LI("vdT.del_list_lk", ADVvdT_del_list_lk_info, SPLNONE, DEFAULT );
	LI("BMT.bfAccessT.mcellList_lk", ADV_BMT_bfAccessT_mcellList_lk_info, SPLNONE, DEFAULT );
	LI("BMT.bfAccessT.xtntMap_lk", ADV_BMT_bfAccessT_xtntMap_lk_info, SPLNONE, DEFAULT );
	LI("domainT.scLock", ADVdomainT_scLock_info, SPLNONE, DEFAULT );
	LI("vdT.rbmt_mcell_lk", ADVvdT_rbmt_mcell_lk_info, SPLNONE, DEFAULT );
	LI("vdT.stgMap_lk", ADVvdT_stgMap_lk_info, SPLNONE, DEFAULT );
        LI("domainT.xidRecoveryLk", ADVdomainT_xidRecoveryLk_info, SPLNONE, DEFAULT );
#endif

#if CMS > 0
        LI("db_qlock_lock", db_qlock_lockinfo, SPLNONE, ORDERED);
#endif /* CMS */

	ULI("chtabhead_lock", chtabhead_lockinfo, SPLNONE, DEFAULT);
	NLI("global_raw_lock", global_raw_li, SPLNONE, DEFAULT);
	NLI("ip6_raw_serial_lock", ip6_raw_serial_li, SPLNONE, DEFAULT);
	NLI("lag_add_del_lock", lag_add_del_li, SPLNONE, DEFAULT);

#if DLM > 0
        LI("dlm_smp_lock", dlm_smp_lockinfo, SPLNONE, DEFAULT);
#endif /* DLM */

#if KCH > 0
	LI("kch_smp_lock", kch_smp_lockinfo, SPLNONE, DEFAULT);
	LI("kch_msg_respq_lock", kch_msg_respq_lockinfo, SPLNONE, DEFAULT);
#endif /* KCH */

#if CNX > 0
        LI("Cnx_smp_lock", Cnx_smp_lockinfo, SPLNONE, DEFAULT);
#endif /* CNX */

	LI("ksm_set_lock", ksm_set_lockinfo, SPLNONE, ORDERED);
	LI("ksm_memb_lock", ksm_memb_lockinfo, SPLNONE, ORDERED);

#if     ICS_HL > 0
        /* Must be above socket lock and domain lock. */
        TNCLI(ics_llnodeinfo_lkdata);
        TNCLI(ics_llnodeinfo_conn_lkdata);
#endif  /* ICS_HL > 0 */

	NLI("ipv6_cfg_lock", ipv6_cfg_li, SPLNONE, DEFAULT);
	NLI("iptunnel_cfg_lock", iptunnel_cfg_li, SPLNONE, DEFAULT);
	NLI("domain_lock", domain_li, SPLNONE, DEFAULT);
	NLI("pmtu_lock", pmtu_li, SPLNONE, DEFAULT);
#if DLI > 0 || DLB > 0
	NLI("dli_input_lock", dli_input_li, SPLNONE, DEFAULT);
#endif
	NLI("socklocks.sock_lock", sock_li, SPLNONE, ORDERED);
	NLI("socklocks.snd_lock", snd_li, SPLNONE, DEFAULT);
	NLI("socklocks.rcv_lock", rcv_li, SPLNONE, DEFAULT);
	NLI("tmt.tmt_lock", tmt_li, SPLNET, DEFAULT);
	NLI("nrlist_lock", nrlist_li, SPLNONE, DEFAULT);
	LI("pgrphash_lock", pgrphash_lockinfo, SPLNONE, DEFAULT);
	ULI("proc.proc_relation_lock", proc_relation_lockinfo, SPLNONE,ORDERED);
	ULI("pgrp.pg_lock", pgrp_lockinfo, SPLNONE, ORDERED);
	LI("cm_lock", cm_lockinfo, SPLNONE, DEFAULT);
	LI("shmidq_lock", shmidq_lockinfo, SPLNONE, DEFAULT);
	LI("shmid_gh_lock", shmid_gh_lockinfo, SPLNONE, DEFAULT);
	LI("gh_lock", gh_lock_lockinfo, SPLNONE, DEFAULT);
	LI("lk_lmf", lk_lmf_lockinfo, SPLNONE, DEFAULT);
	NLI("pr_dom_lock", pr_dom_li, SPLNONE, DEFAULT);
	/* inp_lock must follow socket lock */
	NLI("tcb.inp_lock", inp_tcphead_li, SPLNONE, ORDERED);
	NLI("udb.inp_lock", inp_udphead_li, SPLNONE, ORDERED);
	NLI("rawip6pcb.inp_lock", inp_rawip6head_li, SPLNONE, DEFAULT);
	NLI("in6_laddr_add_del_lock", in6_laddr_add_del_li, SPLNONE, DEFAULT);
#if DLI > 0 || DLB > 0
	NLI("dli_dlif_lock", dli_dlif_li, SPLNONE, DEFAULT);
#endif
	NLI("inifaddr_lock", inifaddr_li, SPLNONE, DEFAULT);
	NLI("igmp_lock", igmp_li, SPLNONE, DEFAULT);
	NLI("mfc_lock", mfc_li, SPLNONE, DEFAULT);
#ifdef RSVP
        NLI("rsvpd_socket_lock", rsvpd_socket_li, SPLNONE, DEFAULT);
#endif
#ifdef INTSERV
        NLI("tcntl.filtbucket_lock", tcntl_filtbucket_lockinfo_i, SPLNONE, DEFAULT);
        NLI("tcntl.flowbucket_lock", tcntl_flowbucket_lockinfo_i, SPLNONE, DEFAULT);
        NLI("tcntl.tcntl_lock", tcntl_tcntl_lockinfo_i, SPLNONE, DEFAULT);
        NLI("tcntl.orphan_lock", tcntl_orphan_lockinfo_i, SPLNONE, DEFAULT);
#endif
#if IPSEC
        ULI("ssh_timeout_run_lock", ssh_timeout_run_lockinfo, SPLNONE, DEFAULT);
        ULI("sshicept_chardev_write_lock", sshicept_chardev_write_lockinfo, SPLNET, DEFAULT);
	ULI("SshKernelMutex_lock", SshKernelMutex_lockinfo, SPLNONE, ORDERED);
        ULI("ssh_interceptor_packet_freelist_lock", ssh_interceptor_packet_freelist_lockinfo, SPLNONE, DEFAULT); 
        ULI("sshicept_chardev_lock", sshicept_chardev_lockinfo, SPLNONE, DEFAULT);
#endif
	NLI("route_lock", route_li, SPLNONE, DEFAULT);
	NLI("mip6_cache_lock", mip6_cache_li, SPLNONE, DEFAULT);
	NLI("mip6_prefix_lock", mip6_prefix_li, SPLNONE, DEFAULT);
	NLI("route6_lock", route6_li, SPLNONE, DEFAULT);
	NLI("if6_nd6_cache_lock", if6_nd6_cache_li, SPLNONE, DEFAULT);
	NLI("ifnet_arp_cache_lock", ifnet_arp_cache_li, SPLNONE, DEFAULT);
	NLI("ip_frag_lock", ip_frag_li, SPLNONE, DEFAULT);
	NLI("ip6_reassq_lock", ip6_reassq_li, SPLNONE, DEFAULT);
        ULI("dyn_hashthread_startup.lock",DYNhashthread_lockinfo,SPLNONE, DEFAULT);

#if NCLUA > 0
        ULI("clua_port_lock", clua_port_lockinfo, SPLNONE, DEFAULT);
        ULI("clua_lock", clua_lockinfo, SPLNONE, DEFAULT);
        ULI("clua_si_lock", clua_si_lockinfo, SPLNONE, DEFAULT);
        ULI("clua_lckq_lock", clua_lckq_lockinfo, SPLNONE, DEFAULT);
	ULI("clua_tunnel_lock", clua_tunnel_lockinfo, SPLNONE, DEFAULT);
#endif

	/*  NTRA || TRSRCF */
	/* srt_thread_lock needs to be after dli_dlif_lock */
	NLI("srt_thread_lock", srtab_li, SPLNONE, DEFAULT);

#if DEC_AUDIT > 0
	ULI("audinit.lock", audinit_lockinfo, SPLNONE, DEFAULT);
#endif

#if NSCSI > 0
	ULI("cam_pd_unit",cam_pd_unit_li,   SPLBIO, DEFAULT);
#endif
	LI("vm_kmap.vm_lock", k_map_lockinfo, SPLNONE, ORDERED);
#if RPTY > 0
	LI("pty_allocation_lock", pty_opcl_lockinfo, SPLNONE, DEFAULT);
#endif

#ifdef ALPHA
	LI("ev_lock", ev_lock_info, SPLNONE, DEFAULT);
#endif ALPHA

	LI("cfg_db_lock", cfg_db_lockinfo, SPLNONE, DEFAULT);
	LI_DISABLE_HIERARCHY_CHECKING(cfg_db_lockinfo);

	LI("subsys_tbl_lock", subsys_tbl_lockinfo, SPLNONE, DEFAULT);
	ULI("hs_srv_lock", hs_srv_lockinfo, SPLNONE, DEFAULT);

#if CMS > 0
        LI("cms_hash_lock", cms_hash_lockinfo, SPLNONE, ORDERED);
        LI("cms_db_reflock", cms_db_reflock_lockinfo, SPLNONE, DEFAULT);
        LI("cms_advfs_domain_lock", cms_advfs_domain_lockinfo, SPLNONE,ORDERED);
#endif

#if AUTOFS > 0
	ULI("autofs_mountinfo_lock", ami_lockinfo, SPLNONE, DEFAULT);
	ULI("autofs_global_lock", autofs_global_lockinfo, SPLNONE, DEFAULT);
#endif

	/*******************************************/
	/* end of lockinfo specs for complex locks */
	/*******************************************/

	/*****************************************************/
	/* start of lockinfo specs for NOCHECK complex locks */
	/*****************************************************/

#if	(CDFS > 0)
	ULI_NOCHECK("cdnode.cd_io_lock", cdfs_inio_lockinfo);
#endif	/* CDFS > 0 */
	ULI_NOCHECK("bdevlock.dsw_lock", bdev_lockinfo);
	ULI_NOCHECK("cdevlock.dsw_lock", cdev_lockinfo);
	ULI_NOCHECK("handler_id_lock", handler_id_lockinfo);
	ULI_NOCHECK("handler_key.lock", handler_key_lockinfo);
	ULI_NOCHECK("ldbl_module_list_lock", ldbl_module_list_lockinfo);
	ULI_NOCHECK("topology_tree_lock", topology_tree_lockinfo);

	/* I/O resource mgmt locks */
	ULI_NOCHECK("res_handle_list_lock", res_handle_list_lockinfo);
	ULI_NOCHECK("resource_key.lock", resource_key_lockinfo);
	ULI_NOCHECK("intr_db_lock", intr_db_lockinfo);
	ULI_NOCHECK("mem_db_lock", mem_db_lockinfo);
	ULI_NOCHECK("io_db_lock", io_db_lockinfo);
	ULI_NOCHECK("io_rsrc_list.lock", resource_entry_lockinfo);
	ULI_NOCHECK("io_res_map_lock", io_res_map_lockinfo);
	ULI_NOCHECK("mem_res_map_lock", mem_res_map_lockinfo);


#if	(NVBA > 0) || (CVBA > 0)
	ULI_NOCHECK("vhp_bus_adapt.shoebox_lk", vhp_shobox_lockinfo);
	ULI_NOCHECK("vhp_bus_adapt.adapt_c_lk", vhp_adapt_c_lockinfo);
#endif	/* (NVBA > 0) || (CVBA > 0) */
#if	(NLV > 0)
	ULI_NOCHECK("volgrp.vg_lock", vg_lockinfo);
	ULI_NOCHECK("lvol.lv_lock", lvtmp_lockinfo);
#endif	/* NLV > 0 */
#if	(NLSM_TED > 0)
	ULI_NOCHECK("ted_cmd_slepp_lock", ted_cmd_slepp_lockinfo);
#endif	/* (NLSM_TED > 0) */
	ULI_NOCHECK("ufsmount.um_lock", umpq_lockinfo);
	ULI_NOCHECK("dqhead.dq_lock", dq_lockinfo);
	ULI_NOCHECK("fifonode.fn_rdio_lock", fifo_rdio_lockinfo);
	ULI_NOCHECK("fifonode.fn_wrio_lock", fifo_wrio_lockinfo);
	ULI_NOCHECK("bp.b_lock", buf_lockinfo);
	ULI_NOCHECK("sleeplck.fichain_lock", sleeplcks_fichain_lockinfo);
	ULI_NOCHECK("grantlcks.fichain_lock", grantlcks_fichain_lockinfo);
	ULI_NOCHECK("klmlcks.fichain_lock", klmlcks_fichain_lock);
	ULI_NOCHECK("vfssw_lock", vfssw_lockinfo);
#if	(NLSM > 0)
	ULI_NOCHECK("volcpybuf_sleep.sl_sleep", vol_alloc_sleep_lockinfo);
#endif	/* NLSM	> 0) */

#if MSFS > 0
	/***************************************************/
	/* start of lockinfo specs for NOCHECK AdvFS locks */
	/***************************************************/

	/* Locks with hierarchy violations */
	ULI_NOCHECK("TraceLock", TraceLock_info);
	ULI_NOCHECK("dQuot.dqLock", ADVdQuot_dqLock_info);
	ULI_NOCHECK("bfAccessT.cow_lk", ADVbfAccessT_cow_lk_info);
	LI("logDescT.descLock", ADVlogDescT_descLock_info, SPLNONE, ORDERED);
	LI("logDescT.flushLock", ADVflushT_flushLock_info, SPLNONE, ORDERED);
	LI_DISABLE_HIERARCHY_CHECKING(ADVflushT_flushLock_info);
	LI_DISABLE_HIERARCHY_CHECKING(ADVlogDescT_descLock_info);
#endif /* MSFS */

#if	(DEC4100 == 1)
        ULI_NOCHECK("i2c_lock", i2c_lockinfo);
#endif /* DEC4100 */

	/***************************************************/
	/* end of lockinfo specs for NOCHECK complex locks */
	/***************************************************/

	LI("lock.l_lock", interlock_lockinfo, SPLNONE, DEFAULT);
	LI_DISABLE_HIERARCHY_CHECKING(interlock_lockinfo);


#if MSFS > 0
	/******************************************/
	/* start of lockinfo specs for PROBE      */
	/* complex locks.			  */
	/******************************************/

	/* fs/fs_create.c PROBES */
	ULI_PROBE("Pfs_create_file", Pfs_create_file_lockinfo);
	ULI_PROBE("Pfs_update_stats", Pfs_update_stats_lockinfo);
	ULI_PROBE("Pfs_flush_saved_stats", Pfs_flush_saved_stats_lockinfo);
	ULI_PROBE("Pfs_trunc_test", Pfs_trunc_test_lockinfo);

	/* fs/fs_dir_init.c PROBES */
	ULI_PROBE("Pfs_init_directory", Pfs_init_directory_lockinfo);
	ULI_PROBE("Pfs_assemble_dir", Pfs_assemble_dir_lockinfo);
	ULI_PROBE("Pdir_empty", Pdir_empty_lockinfo);
	ULI_PROBE("Pfs_create_file_set", Pfs_create_file_set_lockinfo);
	ULI_PROBE("Pcreate_root_file", Pcreate_root_file_lockinfo);
	ULI_PROBE("Pfs_init_ftx", Pfs_init_ftx_lockinfo);
	ULI_PROBE("Pfs_insert_undo", Pfs_insert_undo_lockinfo);

	/* kernel/msfs/fs/fs_file_sets.c */
	ULI_PROBE("Pfs_fset_create", Pfs_fset_create_lockinfo);
	ULI_PROBE("Pfs_fset_get_id", Pfs_fset_get_id_lockinfo);
	ULI_PROBE("Pfs_fset_get_stats", Pfs_fset_get_stats_lockinfo);
	ULI_PROBE("Pfs_fset_delete", Pfs_fset_delete_lockinfo);
	ULI_PROBE("Pfs_fset_clone", Pfs_fset_clone_lockinfo);
	ULI_PROBE("Pfs_fset_get_info", Pfs_fset_get_info_lockinfo);
	ULI_PROBE("Pfs_fset_name_change", Pfs_fset_name_change_lockinfo);
	ULI_PROBE("Pfs_create_frag", Pfs_create_frag_lockinfo);
	ULI_PROBE("Pfs_quick_frag_test", Pfs_quick_frag_test_lockinfo);
	ULI_PROBE("Pfs_delete_frag", Pfs_delete_frag_lockinfo);

        /* kernel/msfs/fs/fs_read_write.c */
        ULI_PROBE("Pfs_zero_fill_pages", Pfs_zero_fill_pages_lockinfo);
        ULI_PROBE("Pfs_read", Pfs_read_lockinfo);
        ULI_PROBE("Pfs_read_direct", Pfs_read_direct_lockinfo);
        ULI_PROBE("Pfs_read_cntxt_access", Pfs_read_cntxt_access_lockinfo);
        ULI_PROBE("Pfs_read_cntxt_vp", Pfs_read_cntxt_vp_lockinfo);
        ULI_PROBE("Pfs_read_cntxt", Pfs_read_cntxt_lockinfo);
        ULI_PROBE("Pfs_read_vp", Pfs_read_vp_lockinfo);
        ULI_PROBE("Pfs_write", Pfs_write_lockinfo);
        ULI_PROBE("Pfs_update_times", Pfs_update_times_lockinfo);
        ULI_PROBE("Pfs_write_direct", Pfs_write_direct_lockinfo);
        ULI_PROBE("Pfs_write_cntxt_vp", Pfs_write_cntxt_vp_lockinfo);
        ULI_PROBE("Pfs_write_add_stg", Pfs_write_add_stg_lockinfo);
        ULI_PROBE("Pcopy_and_del_frag", Pcopy_and_del_frag_lockinfo);
        ULI_PROBE("Pbcopy_frag", Pbcopy_frag_lockinfo);
        ULI_PROBE("Puiomove_frag", Puiomove_frag_lockinfo);

        /* kernel/msfs/fs/fs_quota.c */
        ULI_PROBE("PquotaUndo", PquotaUndo_lockinfo);
        ULI_PROBE("Pchk_quota_write", Pchk_quota_write_lockinfo);
        ULI_PROBE("Pquota_init", Pquota_init_lockinfo);
        ULI_PROBE("Pquota_files_init", Pquota_files_init_lockinfo);
        ULI_PROBE("Pattach_quota", Pattach_quota_lockinfo);
        ULI_PROBE("Pdetach_quota", Pdetach_quota_lockinfo);
        ULI_PROBE("Pchk_blk_quota", Pchk_blk_quota_lockinfo);
        ULI_PROBE("Pchk_bf_quota", Pchk_bf_quota_lockinfo);
        ULI_PROBE("Pchk_bf_quota_chg", Pchk_bf_quota_chg_lockinfo);
        ULI_PROBE("Pvalidate_quota_status", Pvalidate_quota_status_lockinfo);
        ULI_PROBE("Pflush_time_limits", Pflush_time_limits_lockinfo);
        ULI_PROBE("Pget_quota_config", Pget_quota_config_lockinfo);
        ULI_PROBE("Pfs_quota_blks", Pfs_quota_blks_lockinfo);
        ULI_PROBE("Pchkdquot", Pchkdquot_lockinfo);
        ULI_PROBE("Pget_clone_usage_stats", Pget_clone_usage_stats_lockinfo);
        ULI_PROBE("Pget_quota_blks_used", Pget_quota_blks_used_lockinfo);
        ULI_PROBE("Popmntque", Popmntque_lockinfo);
        ULI_PROBE("Pqi_init", Pqi_init_lockinfo);
        ULI_PROBE("Pqf_get", Pqf_get_lockinfo);
        ULI_PROBE("Pquota_activate", Pquota_activate_lockinfo);
        ULI_PROBE("Pquota_deactivate", Pquota_deactivate_lockinfo);
        ULI_PROBE("Padvfs_enforce_on", Padvfs_enforce_on_lockinfo);
        ULI_PROBE("Padvfs_enforce_off", Padvfs_enforce_off_lockinfo);
        ULI_PROBE("Padvfs_maint_on", Padvfs_maint_on_lockinfo);
        ULI_PROBE("Padvfs_maint_off", Padvfs_maint_off_lockinfo);
        ULI_PROBE("Padvfs_quota_chown", Padvfs_quota_chown_lockinfo);
        ULI_PROBE("Padvfs_get_quota", Padvfs_get_quota_lockinfo);
        ULI_PROBE("Padvfs_set_quota", Padvfs_set_quota_lockinfo);
        ULI_PROBE("Padvfs_set_use", Padvfs_set_use_lockinfo);
        ULI_PROBE("Padvfs_quota_sync", Padvfs_quota_sync_lockinfo);
        ULI_PROBE("Pdqget", Pdqget_lockinfo);
        ULI_PROBE("Pdqput", Pdqput_lockinfo);
        ULI_PROBE("Pdqsync",Pdqsync_lockinfo);
        ULI_PROBE("Pquota_page_is_mapped", Pquota_page_is_mapped_lockinfo);

	/* kernel/msfs/osf/msfs_misc.c */
	ULI_PROBE("Posf_fd_to_bfap", Posf_fd_to_bfap_lockinfo);
	ULI_PROBE("Pfscontext_lock_init", Pfscontext_lock_init_lockinfo);
	ULI_PROBE("Pvnode_fscontext_allocate", Pvnode_fscontext_allocate_lockinfo);
	ULI_PROBE("Pvnode_fscontext_deallocate", Pvnode_fscontext_deallocate_lockinfo);
	ULI_PROBE("Pbf_get_l", Pbf_get_l_lockinfo);
	ULI_PROBE("Pmsfs_inactive", Pmsfs_inactive_lockinfo);
	ULI_PROBE("Pmsfs_reclaim", Pmsfs_reclaim_lockinfo);
	ULI_PROBE("Pcopy_frag_into_vm_page", Pcopy_frag_into_vm_page_lockinfo);
	ULI_PROBE("Pmsfs_putpage", Pmsfs_putpage_lockinfo);
	ULI_PROBE("Pmsfs_getpage", Pmsfs_getpage_lockinfo);
        ULI_PROBE("Pmsfs_write_check", Pmsfs_write_check_lockinfo);
	ULI_PROBE("Pcopy_frag_into_page", Pcopy_frag_into_page_lockinfo);
	ULI_PROBE("Pmsfs_mmap", Pmsfs_mmap_lockinfo);
	ULI_PROBE("Pmsfs_bread", Pmsfs_bread_lockinfo);
	ULI_PROBE("Pmsfs_brelse", Pmsfs_brelse_lockinfo);
	ULI_PROBE("Pmsfs_fs_replicate", Pmsfs_fs_replicate_lockinfo);
	ULI_PROBE("Pmsfs_log_and_meta_flush", Pmsfs_log_and_meta_flush_lockinfo);

	/* kernel/msfs/osf/msfs_vnops.c */
        ULI_PROBE("Pmsfs_create", Pmsfs_create_lockinfo);
        ULI_PROBE("Pmsfs_mknod", Pmsfs_mknod_lockinfo);
        ULI_PROBE("Pmsfs_close", Pmsfs_close_lockinfo);
        ULI_PROBE("Pmsfs_access", Pmsfs_access_lockinfo);
        ULI_PROBE("Pmsfs_getattr", Pmsfs_getattr_lockinfo);
        ULI_PROBE("Pmsfs_setattr", Pmsfs_setattr_lockinfo);
        ULI_PROBE("Pmsfs_read", Pmsfs_read_lockinfo);
        ULI_PROBE("Pmsfs_write", Pmsfs_write_lockinfo);
        ULI_PROBE("Pmsfs_ioctl", Pmsfs_ioctl_lockinfo);
        ULI_PROBE("Pmsfs_fsync", Pmsfs_fsync_lockinfo);
        ULI_PROBE("Pmsfs_seek", Pmsfs_seek_lockinfo);
        ULI_PROBE("Pmsfs_remove", Pmsfs_remove_lockinfo);
        ULI_PROBE("Pmsfs_link", Pmsfs_link_lockinfo);
        ULI_PROBE("Pmsfs_rename", Pmsfs_rename_lockinfo);
        ULI_PROBE("Pdecr_link_count", Pdecr_link_count_lockinfo);
        ULI_PROBE("Pmsfs_mkdir", Pmsfs_mkdir_lockinfo);
        ULI_PROBE("Pmsfs_rmdir", Pmsfs_rmdir_lockinfo);
        ULI_PROBE("Pmsfs_symlink", Pmsfs_symlink_lockinfo);
        ULI_PROBE("Pmsfs_readdir", Pmsfs_readdir_lockinfo);
        ULI_PROBE("Pmsfs_readlink", Pmsfs_readlink_lockinfo);
        ULI_PROBE("Pmsfs_strategy", Pmsfs_strategy_lockinfo);
        ULI_PROBE("Pmsfs_page_read", Pmsfs_page_read_lockinfo);
        ULI_PROBE("Pmsfs_page_write", Pmsfs_page_write_lockinfo);
        ULI_PROBE("Pmsfsspec_read", Pmsfsspec_read_lockinfo);
        ULI_PROBE("Pmsfsspec_write", Pmsfsspec_write_lockinfo);
        ULI_PROBE("Pmsfsspec_close", Pmsfsspec_close_lockinfo);
        ULI_PROBE("Pmsfsspec_reclaim", Pmsfsspec_reclaim_lockinfo);
        ULI_PROBE("Pmsfsfifo_read", Pmsfsfifo_read_lockinfo);
        ULI_PROBE("Pmsfsfifo_write", Pmsfsfifo_write_lockinfo);
        ULI_PROBE("Pmsfsfifo_close", Pmsfsfifo_close_lockinfo);
        ULI_PROBE("Pmsfsfifo_getattr", Pmsfsfifo_getattr_lockinfo);
        ULI_PROBE("Pmsfsfifo_reclaim", Pmsfsfifo_reclaim_lockinfo);
        ULI_PROBE("Pmsfs_chown", Pmsfs_chown_lockinfo);
        ULI_PROBE("Pmsfs_chmod", Pmsfs_chmod_lockinfo);
        ULI_PROBE("Pattach_undel_dir", Pattach_undel_dir_lockinfo);
        ULI_PROBE("Pdetach_undel_dir", Pdetach_undel_dir_lockinfo);
        ULI_PROBE("Pget_undel_dir", Pget_undel_dir_lockinfo);
        ULI_PROBE("Pget_name", Pget_name_lockinfo);
        ULI_PROBE("Pget_name2", Pget_name2_lockinfo);
        ULI_PROBE("Pmsfs_lockctl", Pmsfs_lockctl_lockinfo);
        ULI_PROBE("Pmsfs_setvlocks", Pmsfs_setvlocks_lockinfo);
        ULI_PROBE("Pmsfs_syncdata", Pmsfs_syncdata_lockinfo);

	/* kernel/msfs/bs/bs_access.c */

	ULI_PROBE("Pinit_access", Pinit_access_lockinfo);
	ULI_PROBE("Pget_free_acc", Pget_free_acc_lockinfo);
	ULI_PROBE("Pfind_bfap", Pfind_bfap_lockinfo);
	ULI_PROBE("Paccess_invalidate", Paccess_invalidate_lockinfo);
	ULI_PROBE("Pbs_inval_rsvd_acc_st", Pbs_inval_rsvd_acc_st_lockinfo);
        ULI_PROBE("Pbs_reclaim_cfs_rsvd_vn", Pbs_reclaim_cfs_rsvd_vn_lockinfo);
	ULI_PROBE("Pbs_init_area", Pbs_init_area_lockinfo);
	ULI_PROBE("Pbs_map_bf", Pbs_map_bf_lockinfo);
	ULI_PROBE("Pbs_insmntque", Pbs_insmntque_lockinfo);
	ULI_PROBE("Pbfm_open_ms", Pbfm_open_ms_lockinfo);
	ULI_PROBE("Pbs_access", Pbs_access_lockinfo);
	ULI_PROBE("Pbs_access_one", Pbs_access_one_lockinfo);
	ULI_PROBE("Pget_n_setup_new_vnode", Pget_n_setup_new_vnode_lockinfo);
	ULI_PROBE("Pgrab_bsacc", Pgrab_bsacc_lockinfo);
	ULI_PROBE("Pbs_close", Pbs_close_lockinfo);
	ULI_PROBE("Pbs_close_one", Pbs_close_one_lockinfo);
	ULI_PROBE("Pfree_acc_struct", Pfree_acc_struct_lockinfo);
	ULI_PROBE("Pbf_setup_truncation", Pbf_setup_truncation_lockinfo);
	ULI_PROBE("Pbs_get_current_tag", Pbs_get_current_tag_lockinfo);
	ULI_PROBE("Pbs_dealloc_access", Pbs_dealloc_access_lockinfo);
	ULI_PROBE("Pbs_init_access_alloc_thread", Pbs_init_access_alloc_thread_lockinfo);
	ULI_PROBE("Pbs_access_alloc_thread", Pbs_access_alloc_thread_lockinfo);
	ULI_PROBE("Pcheck_busy", Pcheck_busy_lockinfo);
	ULI_PROBE("Pcheck_mv_bfap_to_free", Pcheck_mv_bfap_to_free_lockinfo);
	ULI_PROBE("Pcleanup_closed_list", Pcleanup_closed_list_lockinfo);	
	ULI_PROBE("Pbfs_flush_dirty_stats", Pbfs_flush_dirty_stats_lockinfo);
	ULI_PROBE("Pcheck_closed_list", Pcheck_closed_list_lockinfo);
	ULI_PROBE("Pinsert_actRange_onto_list", Pinsert_actRange_onto_list_lockinfo);
	ULI_PROBE("Premove_actRange_from_list", Premove_actRange_from_list_lockinfo);

	/* kernel/msfs/bs/bs_bmt_util.c		*/

	ULI_PROBE("Palloc_link_mcell_undo", Palloc_link_mcell_undo_lockinfo);
	ULI_PROBE("Palloc_mcell", Palloc_mcell_lockinfo);
	ULI_PROBE("Palloc_mcell_undo", Palloc_mcell_undo_lockinfo);
	ULI_PROBE("Palloc_rbmt_mcell", Palloc_rbmt_mcell_lockinfo);
	ULI_PROBE("Pbmt_alloc_link_mcell", Pbmt_alloc_link_mcell_lockinfo);
	ULI_PROBE("Pbmt_alloc_mcell", Pbmt_alloc_mcell_lockinfo);
	ULI_PROBE("Pbmt_alloc_prim_mcell", Pbmt_alloc_prim_mcell_lockinfo);
	ULI_PROBE("Pbmt_alloc_prim_mcell", Pbmt_alloc_prim_mcell_lockinfo);
	ULI_PROBE("Pbmt_close", Pbmt_close_lockinfo);
	ULI_PROBE("Pbmt_extend", Pbmt_extend_lockinfo);
	ULI_PROBE("Pbmt_find_mcell", Pbmt_find_mcell_lockinfo);
	ULI_PROBE("Pbmt_free_bf_mcells", Pbmt_free_bf_mcells_lockinfo);
	ULI_PROBE("Pbmt_free_bf_mcells_i", Pbmt_free_bf_mcells_i_lockinfo);
	ULI_PROBE("Pbmt_free_mcell", Pbmt_free_mcell_lockinfo);
	ULI_PROBE("Pbmt_get_vd_bf_descs", Pbmt_get_vd_bf_descs_lockinfo);
	ULI_PROBE("Pbmt_init_page", Pbmt_init_page_lockinfo);
	ULI_PROBE("Pbmt_link_mcells", Pbmt_link_mcells_lockinfo);
	ULI_PROBE("Pbmt_open", Pbmt_open_lockinfo);
	ULI_PROBE("Pbmt_read", Pbmt_read_lockinfo);
	ULI_PROBE("Pbmt_set_mcell_free_list", Pbmt_set_mcell_free_list_lockinfo);
	ULI_PROBE("Pbmt_unlink_mcells", Pbmt_unlink_mcells_lockinfo);
	ULI_PROBE("Pbmt_upd_mcell_free_list", Pbmt_upd_mcell_free_list_lockinfo);
	ULI_PROBE("Pbmtr_assign", Pbmtr_assign_lockinfo);
	ULI_PROBE("Pbmtr_assign_rec", Pbmtr_assign_rec_lockinfo);
	ULI_PROBE("Pbmtr_clone_mcell", Pbmtr_clone_mcell_lockinfo);
	ULI_PROBE("Pbmtr_clone_recs", Pbmtr_clone_recs_lockinfo);
	ULI_PROBE("Pbmtr_create_rec", Pbmtr_create_rec_lockinfo);
	ULI_PROBE("Pbmtr_find", Pbmtr_find_lockinfo);
	ULI_PROBE("Pbmtr_get_rec_n_lk", Pbmtr_get_rec_n_lk_lockinfo);
	ULI_PROBE("Pbmtr_get_rec_ptr", Pbmtr_get_rec_ptr_lockinfo);
	ULI_PROBE("Pbmtr_put_rec_n_unlk", Pbmtr_put_rec_n_unlk_lockinfo);
	ULI_PROBE("Pbmtr_put_rec_n_unlk_int", Pbmtr_put_rec_n_unlk_int_lockinfo);
	ULI_PROBE("Pbmtr_put_rec_undo_opx", Pbmtr_put_rec_undo_opx_lockinfo);
	ULI_PROBE("Pbmtr_scan", Pbmtr_scan_lockinfo);
	ULI_PROBE("Pbmtr_scan_mcells", Pbmtr_scan_mcells_lockinfo);
	ULI_PROBE("Pbmtr_update_rec", Pbmtr_update_rec_lockinfo);
	ULI_PROBE("Pbmtr_update_rec_int", Pbmtr_update_rec_int_lockinfo);
	ULI_PROBE("Pbmtr_update_rec_n_unlk", Pbmtr_update_rec_n_unlk_lockinfo);
	ULI_PROBE("Pextend_bmt_redo_opx", Pextend_bmt_redo_opx_lockinfo);
	ULI_PROBE("Pfree_mcell_chains_opx", Pfree_mcell_chains_opx_lockinfo);
	ULI_PROBE("Pinit_bs_bmt_util_opx", Pinit_bs_bmt_util_opx_lockinfo);
	ULI_PROBE("Pinit_mcell", Pinit_mcell_lockinfo);
	ULI_PROBE("Plink_mcells", Plink_mcells_lockinfo);
	ULI_PROBE("Plink_unlink_mcells_undo", Plink_unlink_mcells_undo_lockinfo);
	ULI_PROBE("Pallocate_link_new_mcell", Pallocate_link_new_mcell_lockinfo);
	ULI_PROBE("Pbmtr_find_check", Pbmtr_find_check_lockinfo);
	ULI_PROBE("Pbs_init_rbmt_thread", Pbs_init_rbmt_thread_lockinfo);
	ULI_PROBE("Pbs_extend_rbmt_thread", Pbs_extend_rbmt_thread_lockinfo);
        ULI_PROBE("Ptest_mcell_ptr", Ptest_mcell_ptr_lockinfo);
        ULI_PROBE("Pcheck_mcell_ptr", Pcheck_mcell_ptr_lockinfo);
        ULI_PROBE("Pcheck_BMT_pg", Pcheck_BMT_pg_lockinfo);
        ULI_PROBE("Pcheck_mcell_hdr", Pcheck_mcell_hdr_lockinfo);
        ULI_PROBE("Pcheck_BSR_XTNTS_rec", Pcheck_BSR_XTNTS_rec_lockinfo);
        ULI_PROBE("Pcheck_BSR_SHADOW_XTNTS_rec", Pcheck_BSR_SHADOW_XTNTS_rec_lockinfo);
        ULI_PROBE("Pcheck_BSR_XTRA_XTNTS_rec", Pcheck_BSR_XTRA_XTNTS_rec_lockinfo);
        ULI_PROBE("Pcheck_xtnts", Pcheck_xtnts_lockinfo);
	ULI_PROBE("Prbmt_extend", Prbmt_extend_lockinfo);
	ULI_PROBE("Pextend_rbmt_redo_opx", Pextend_rbmt_redo_opx_lockinfo);
	ULI_PROBE("Palloc_rbmt_mcell", Palloc_rbmt_mcell_lockinfo);
	ULI_PROBE("Palloc_rbmt_mcell_undo", Palloc_rbmt_mcell_undo_lockinfo);

	/* kernel/msfs/bs/bs_domain.c		*/

	ULI_PROBE("Pbs_bfdmn_activate", Pbs_bfdmn_activate_lockinfo);
	ULI_PROBE("Pbs_bfdmn_deactivate", Pbs_bfdmn_deactivate_lockinfo);
	ULI_PROBE("Pbs_bfdmn_flush", Pbs_bfdmn_flush_lockinfo);
	ULI_PROBE("Pbs_bfdmn_flush_all", Pbs_bfdmn_flush_all_lockinfo);
	ULI_PROBE("Pbs_bfdmn_flush_bfrs", Pbs_bfdmn_flush_bfrs_lockinfo);
	ULI_PROBE("Pbs_bfdmn_flush_sync", Pbs_bfdmn_flush_sync_lockinfo);
	ULI_PROBE("Pbs_bfdmn_id_activate", Pbs_bfdmn_id_activate_lockinfo);
	ULI_PROBE("Pbs_bfdmn_tbl_activate", Pbs_bfdmn_tbl_activate_lockinfo);
	ULI_PROBE("Pbs_bfset_get_dev", Pbs_bfset_get_dev_lockinfo);
	ULI_PROBE("Pbs_dmn_change", Pbs_dmn_change_lockinfo);
	ULI_PROBE("Pbs_domain_access", Pbs_domain_access_lockinfo);
	ULI_PROBE("Pbs_domain_close", Pbs_domain_close_lockinfo);
	ULI_PROBE("Pbs_get_dmntbl_params", Pbs_get_dmntbl_params_lockinfo);
	ULI_PROBE("Pbs_vd_add_active", Pbs_vd_add_active_lockinfo);
	ULI_PROBE("Pbs_vd_remove_active", Pbs_vd_remove_active_lockinfo);
	ULI_PROBE("Pbs_vd_add_rem_vol_done", Pbs_vd_add_rem_vol_done_lockinfo);
	ULI_PROBE("Pclear_bmt", Pclear_bmt_lockinfo);
	ULI_PROBE("Pdmn_alloc", Pdmn_alloc_lockinfo);
	ULI_PROBE("Pdmn_dealloc", Pdmn_dealloc_lockinfo);
	ULI_PROBE("Pdomain_lookup", Pdomain_lookup_lockinfo);
	ULI_PROBE("Pdomain_name_lookup", Pdomain_name_lookup_lockinfo);
	ULI_PROBE("Pfind_del_entry", Pfind_del_entry_lockinfo);
	ULI_PROBE("Pfree_vdds", Pfree_vdds_lockinfo);
	ULI_PROBE("Pget_domain_disks", Pget_domain_disks_lockinfo);
	ULI_PROBE("Pget_domain_major", Pget_domain_major_lockinfo);
	ULI_PROBE("Pget_raw_vd_attrs", Pget_raw_vd_attrs_lockinfo);
	ULI_PROBE("Pget_vdd", Pget_vdd_lockinfo);
	ULI_PROBE("Pmega_presto_start", Pmega_presto_start_lockinfo);
	ULI_PROBE("Pmega_touch_presto", Pmega_touch_presto_lockinfo);
	ULI_PROBE("Pscan_rsvd_file_xtnt_map", Pscan_rsvd_file_xtnt_map_lockinfo);
	ULI_PROBE("Pset_disk_attrs", Pset_disk_attrs_lockinfo);
	ULI_PROBE("Pset_vd_mounted", Pset_vd_mounted_lockinfo);
	ULI_PROBE("Psetup_vd", Psetup_vd_lockinfo);
	ULI_PROBE("Pvd_alloc", Pvd_alloc_lockinfo);
	ULI_PROBE("Pvd_alloc_index", Pvd_alloc_index_lockinfo);
	ULI_PROBE("Pvd_free", Pvd_free_lockinfo);
	ULI_PROBE("Pvd_remove", Pvd_remove_lockinfo);
	ULI_PROBE("Pwait_for_ddl_active_entry", Pwait_for_ddl_active_entry_lockinfo);
	ULI_PROBE("Pset_recovery_failed", Pset_recovery_failed_lockinfo);
	ULI_PROBE("Padvfs_enum_domain_devts", Padvfs_enum_domain_devts_lockinfo);
	ULI_PROBE("Pvd_htop_if_valid", Pvd_htop_if_valid_lockinfo);
	ULI_PROBE("Pvd_htop_already_valid", Pvd_htop_already_valid_lockinfo);
	ULI_PROBE("Pvd_dec_refcnt", Pvd_dec_refcnt_lockinfo);
	ULI_PROBE("Pcheck_trans_attrs", Pcheck_trans_attrs_lockinfo);
	ULI_PROBE("Pclear_trans_attrs", Pclear_trans_attrs_lockinfo);
	ULI_PROBE("Pbs_fix_root_dmn", Pbs_fix_root_dmn_lockinfo);
	ULI_PROBE("Pbs_check_root_dmn_sc", Pbs_check_root_dmn_sc_lockinfo);

	/* kernel/msfs/bs/bs_extents.c		*/

	ULI_PROBE("Pcreate_xtnt_map_hdr", Pcreate_xtnt_map_hdr_lockinfo);
	ULI_PROBE("Pinit_bs_xtnts_opx", Pinit_bs_xtnts_opx_lockinfo);
	ULI_PROBE("Pload_from_bmt_xtra_xtnt_rec", Pload_from_bmt_xtra_xtnt_rec_lockinfo);
	ULI_PROBE("Pload_from_shadow_rec", Pload_from_shadow_rec_lockinfo);
	ULI_PROBE("Pload_from_xtnt_array", Pload_from_xtnt_array_lockinfo);
	ULI_PROBE("Pload_from_xtnt_rec", Pload_from_xtnt_rec_lockinfo);
	ULI_PROBE("Pload_from_xtra_xtnt_rec", Pload_from_xtra_xtnt_rec_lockinfo);
	ULI_PROBE("Pload_inmem_xtnt_map", Pload_inmem_xtnt_map_lockinfo);
#ifdef ADVFS_DEBUG
	ULI_PROBE("Podm_check_xtnt_map", Podm_check_xtnt_map_lockinfo);
	ULI_PROBE("Podm_print_xtnt_map", Podm_print_xtnt_map_lockinfo);
#endif /* ADVFS_DEBUG */
	ULI_PROBE("Podm_create_xtnt_map", Podm_create_xtnt_map_lockinfo);
	ULI_PROBE("Podm_create_xtnt_rec", Podm_create_xtnt_rec_lockinfo);
	ULI_PROBE("Podm_remove_mcells_from_xtnt_map", Podm_remove_mcells_from_xtnt_map_lockinfo);
	ULI_PROBE("Podm_rewrite_xtnt_map", Podm_rewrite_xtnt_map_lockinfo);
	ULI_PROBE("Pundo_insert_remove_xtnt_chain", Pundo_insert_remove_xtnt_chain_lockinfo);
	ULI_PROBE("Pundo_mcell_cnt", Pundo_mcell_cnt_lockinfo);
	ULI_PROBE("Pundo_upd_xtnt_rec", Pundo_upd_xtnt_rec_lockinfo);
	ULI_PROBE("Pupdate_mcell_cnt", Pupdate_mcell_cnt_lockinfo);
	ULI_PROBE("Pupdate_xtnt_array", Pupdate_xtnt_array_lockinfo);
	ULI_PROBE("Pupdate_xtnt_rec", Pupdate_xtnt_rec_lockinfo);
	ULI_PROBE("Px_create_inmem_xtnt_map", Px_create_inmem_xtnt_map_lockinfo);
	ULI_PROBE("Px_create_shadow_rec", Px_create_shadow_rec_lockinfo);
	ULI_PROBE("Px_load_inmem_xtnt_map", Px_load_inmem_xtnt_map_lockinfo);
	ULI_PROBE("Px_update_ondisk_xtnt_map", Px_update_ondisk_xtnt_map_lockinfo);
	ULI_PROBE("Px_update_ondisk_rbmt_xtnt_map", Px_update_ondisk_rbmt_xtnt_map_lockinfo);
	ULI_PROBE("Pload_from_rbmt_xtnt_rec", Pload_from_rbmt_xtnt_rec_lockinfo);

    /* kernel/msfs/bs/bs_index.c */
    ULI_PROBE("Pidx_create_index_file_int", Pidx_create_index_file_int_lockinfo);
    ULI_PROBE("Pidx_remove_index_file", Pidx_remove_index_file_lockinfo);
    ULI_PROBE("Pidx_open_index_file", Pidx_open_index_file_lockinfo);
    ULI_PROBE("Pidx_close_index_file", Pidx_close_index_file_lockinfo);
    ULI_PROBE("Pidx_bsearch_int", Pidx_bsearch_int_lockinfo);
    ULI_PROBE("Pidx_hash_filename_int", Pidx_hash_filename_int_lockinfo);
    ULI_PROBE("Pidx_index_get_free_pgs_int", Pidx_index_get_free_pgs_int_lockinfo);
    ULI_PROBE("Pidx_split_node_int", Pidx_split_node_int_lockinfo);
    ULI_PROBE("Pidx_insert_filename", Pidx_insert_filename_lockinfo);
    ULI_PROBE("Pidx_insert_filename_int", Pidx_insert_filename_int_lockinfo);
    ULI_PROBE("Pidx_remove_filename", Pidx_remove_filename_lockinfo);
    ULI_PROBE("Pidx_remove_filename_int", Pidx_remove_filename_int_lockinfo);
    ULI_PROBE("Pidx_lookup_filename", Pidx_lookup_filename_lockinfo);
    ULI_PROBE("Pidx_lookup_node_int", Pidx_lookup_node_int_lockinfo);
    ULI_PROBE("Pidx_directory_insert_space", Pidx_directory_insert_space_lockinfo);
    ULI_PROBE("Pidx_directory_insert_space_int", Pidx_directory_insert_space_int_lockinfo);
    ULI_PROBE("Pidx_directory_get_space", Pidx_directory_get_space_lockinfo);
    ULI_PROBE("Pidx_directory_get_space_int", Pidx_directory_get_space_int_lockinfo);;
    ULI_PROBE("Pidx_setup_for_truncation", Pidx_setup_for_truncation_lockinfo);
    ULI_PROBE("Pidx_setup_for_truncation_int", Pidx_setup_for_truncation_int_lockinfo);
    ULI_PROBE("Pidx_glom_entry_int", Pidx_glom_entry_int_lockinfo);
    ULI_PROBE("Pidx_convert_dir", Pidx_convert_dir_lockinfo);
    ULI_PROBE("Pdir_sort_int", Pdir_sort_int_lockinfo);
    ULI_PROBE("Pidx_prune_start", Pidx_prune_start_lockinfo);
    ULI_PROBE("Pidx_prune_btree_int", Pidx_prune_btree_int_lockinfo);
    ULI_PROBE("Pidx_remove_page_of_storage_int", Pidx_remove_page_of_storage_int_lockinfo);
    ULI_PROBE("Pidx_prune_finish", Pidx_prune_finish_lockinfo);
    ULI_PROBE("Pidx_undo_opx", Pidx_undo_opx_lockinfo);
    ULI_PROBE("Pidx_directory_insert_space_undo", Pidx_directory_insert_space_undo_lockinfo);

	/* kernel/msfs/bs/bs_init.c		*/

	ULI_PROBE("Pbs_dmn_init", Pbs_dmn_init_lockinfo);
	ULI_PROBE("Pbs_disk_init", Pbs_disk_init_lockinfo);
	ULI_PROBE("Pbmt_init_mcell_free_list", Pbmt_init_mcell_free_list_lockinfo);
	ULI_PROBE("Pdel_init_mcell_list", Pdel_init_mcell_list_lockinfo);
	ULI_PROBE("Ptagdir_init_pg0", Ptagdir_init_pg0_lockinfo);
	ULI_PROBE("Pinit_sbm", Pinit_sbm_lockinfo);
	ULI_PROBE("Pbs_disk_init_v3", Pbs_disk_init_v3_lockinfo);

	/* kernel/msfs/bs/bs_inmem_map.c	*/

	ULI_PROBE("Pimm_create_xtnt_map", Pimm_create_xtnt_map_lockinfo);
	ULI_PROBE("Pimm_init_xtnt_map", Pimm_init_xtnt_map_lockinfo);
	ULI_PROBE("Pimm_extend_xtnt_map", Pimm_extend_xtnt_map_lockinfo);
	ULI_PROBE("Pimm_big_extend_xtnt_map", Pimm_big_extend_xtnt_map_lockinfo);
	ULI_PROBE("Pimm_get_first_xtnt_desc", Pimm_get_first_xtnt_desc_lockinfo);
	ULI_PROBE("Pimm_get_xtnt_desc", Pimm_get_xtnt_desc_lockinfo);
	ULI_PROBE("Pimm_get_next_xtnt_desc", Pimm_get_next_xtnt_desc_lockinfo);
	ULI_PROBE("Pimm_delete_xtnt_map", Pimm_delete_xtnt_map_lockinfo);
	ULI_PROBE("Pimm_delete_sub_xtnt_maps", Pimm_delete_sub_xtnt_maps_lockinfo);
	ULI_PROBE("Pimm_init_sub_xtnt_map", Pimm_init_sub_xtnt_map_lockinfo);
	ULI_PROBE("Pimm_copy_xtnt_map", Pimm_copy_xtnt_map_lockinfo);
	ULI_PROBE("Pimm_copy_sub_xtnt_map", Pimm_copy_sub_xtnt_map_lockinfo);
	ULI_PROBE("Pimm_extend_sub_xtnt_map", Pimm_extend_sub_xtnt_map_lockinfo);
	ULI_PROBE("Pimm_load_sub_xtnt_map", Pimm_load_sub_xtnt_map_lockinfo);
	ULI_PROBE("Pimm_unload_sub_xtnt_map", Pimm_unload_sub_xtnt_map_lockinfo);
	ULI_PROBE("Pimm_copy_xtnt_descs", Pimm_copy_xtnt_descs_lockinfo);
	ULI_PROBE("Pimm_split_desc", Pimm_split_desc_lockinfo);
	ULI_PROBE("Pmm_get_alloc_page_cnt", Pmm_get_alloc_page_cnt_lockinfo);
	ULI_PROBE("Pget_sub_xtnt_map_alloc_page_cnt", Pget_sub_xtnt_map_alloc_page_cnt_lockinfo);
	ULI_PROBE("Pimm_get_next_page", Pimm_get_next_page_lockinfo);
	ULI_PROBE("Pimm_get_first_hole", Pimm_get_first_hole_lockinfo);
	ULI_PROBE("Pimm_get_hole_size", Pimm_get_hole_size_lockinfo);
	ULI_PROBE("Pimm_get_page_type", Pimm_get_page_type_lockinfo);
	ULI_PROBE("Pimm_set_next_valid_copy_page", Pimm_set_next_valid_copy_page_lockinfo);
	ULI_PROBE("Pimm_page_to_sub_xtnt_map", Pimm_page_to_sub_xtnt_map_lockinfo);
	ULI_PROBE("Pimm_page_to_xtnt", Pimm_page_to_xtnt_lockinfo);
	ULI_PROBE("Pimm_overlay_xtnt_map", Pimm_overlay_xtnt_map_lockinfo);
	ULI_PROBE("Pimm_merge_xtnt_map", Pimm_merge_xtnt_map_lockinfo);
	ULI_PROBE("Pimm_remove_page_map", Pimm_remove_page_map_lockinfo);
#ifdef ADVFS_DEBUG
	ULI_PROBE("Pimm_check_xtnt_map", Pimm_check_xtnt_map_lockinfo);
	ULI_PROBE("Pimm_print_xtnt_map", Pimm_print_xtnt_map_lockinfo);
#endif /* ADVFS_DEBUG */
    ULI_PROBE("Pimm_get_xtnt_map_size", Pimm_get_xtnt_map_size_lockinfo);
    ULI_PROBE("Pfree_xtntmap", Pfree_xtntmap_lockinfo);
    ULI_PROBE("Pget_real_xtntmap", Pget_real_xtntmap_lockinfo);
    ULI_PROBE("Padvfs_get_extent_map", Padvfs_get_extent_map_lockinfo);

	/* kernel/msfs/bs/bs_migrate.c		*/

	ULI_PROBE("Pmig_register_migrate_agent", Pmig_register_migrate_agent_lockinfo);
	ULI_PROBE("Pbs_migrate", Pbs_migrate_lockinfo);
	ULI_PROBE("Pmig_migrate", Pmig_migrate_lockinfo);
	ULI_PROBE("Pmigrate_normal_one_disk", Pmigrate_normal_one_disk_lockinfo);
	ULI_PROBE("Pmigrate_normal", Pmigrate_normal_lockinfo);
	ULI_PROBE("Pmigrate_stripe", Pmigrate_stripe_lockinfo);
	ULI_PROBE("Pget_xm_page_range_info", Pget_xm_page_range_info_lockinfo);
	ULI_PROBE("Pextend_page_range_list", Pextend_page_range_list_lockinfo);
	ULI_PROBE("Pswitch_stg", Pswitch_stg_lockinfo);
	ULI_PROBE("Pbs_move_metadata", Pbs_move_metadata_lockinfo);
	ULI_PROBE("Pmove_metadata", Pmove_metadata_lockinfo);
	ULI_PROBE("Preset_block_map", Preset_block_map_lockinfo);
	ULI_PROBE("Palloc_copy_stg", Palloc_copy_stg_lockinfo);
	ULI_PROBE("Palloc_hole_stg", Palloc_hole_stg_lockinfo);
	ULI_PROBE("Palloc_hole_stg_mig", Palloc_hole_stg_mig_lockinfo);

	/* kernel/msfs/bs/bs_misc.c		*/

	ULI_PROBE("Pcheck_privilege", Pcheck_privilege_lockinfo);
        ULI_PROBE("Pcopyin_domain_and_set_names", Pcopyin_domain_and_set_names_lockinfo);
        ULI_PROBE("Pfree_domain_and_set_names", Pfree_domain_and_set_names_lockinfo);
	ULI_PROBE("Popen_domain", Popen_domain_lockinfo);
	ULI_PROBE("Popen_set", Popen_set_lockinfo);
	ULI_PROBE("Pmsfs_real_syscall", Pmsfs_real_syscall_lockinfo);
	ULI_PROBE("Pbs_inherit", Pbs_inherit_lockinfo);
	ULI_PROBE("Pbs_inherit_init", Pbs_inherit_init_lockinfo);
	ULI_PROBE("Pbs_get_global_stats", Pbs_get_global_stats_lockinfo);
	ULI_PROBE("Pmsfs_process_deferred_delete_list", Pmsfs_process_deferred_delete_list_lockinfo);
	ULI_PROBE("Pmsfs_set_domain_relocating_flag", Pmsfs_set_domain_relocating_flag_lockinfo);

	/* kernel/msfs/bs/bs_msg_queue.c */
	ULI_PROBE("Pmsgq_create", Pmsgq_create_lockinfo);
	ULI_PROBE("Pmsgq_alloc_msg", Pmsgq_alloc_msg_lockinfo);
	ULI_PROBE("Pmsgq_send_msg", Pmsgq_send_msg_lockinfo);
	ULI_PROBE("Pmsgq_recv_msg", Pmsgq_recv_msg_lockinfo);
	ULI_PROBE("Pmsgq_free_msg", Pmsgq_free_msg_lockinfo);
	ULI_PROBE("Pulmq_alloc_msg", Pulmq_alloc_msg_lockinfo);
	ULI_PROBE("Pulmq_init_freelist", Pulmq_init_freelist_lockinfo);
	ULI_PROBE("Pulmq_send_msg", Pulmq_send_msg_lockinfo);
	ULI_PROBE("Pulmq_recv_msg", Pulmq_recv_msg_lockinfo);
	ULI_PROBE("Pulmq_free_msg", Pulmq_free_msg_lockinfo);

    /* bs/bs_buffer2.c PROBE stuff */
    ULI_PROBE("Pbs_get_bsbuf", Pbs_get_bsbuf_lockinfo);
    ULI_PROBE("Pbs_free_bsbuf", Pbs_free_bsbuf_lockinfo);
    ULI_PROBE("Pblkmap", Pblkmap_lockinfo);
    ULI_PROBE("Pblkmap_direct", Pblkmap_direct_lockinfo);
    ULI_PROBE("Pbs_refpg_get", Pbs_refpg_get_lockinfo);
    ULI_PROBE("Pbs_refpg", Pbs_refpg_lockinfo);
    ULI_PROBE("Pbs_refpg_direct", Pbs_refpg_direct_lockinfo);
    ULI_PROBE("Pbs_refpg_fetch", Pbs_refpg_fetch_lockinfo);
    ULI_PROBE("Pbs_refpg_int", Pbs_refpg_int_lockinfo);
    ULI_PROBE("Pbs_refpg_newpage", Pbs_refpg_newpage_lockinfo);
    ULI_PROBE("Pbs_derefpg", Pbs_derefpg_lockinfo);
    ULI_PROBE("Pbs_pinpg_direct", Pbs_pinpg_direct_lockinfo);
    ULI_PROBE("Pbs_pinpg_clone", Pbs_pinpg_clone_lockinfo);
    ULI_PROBE("Pbs_pinpg_int", Pbs_pinpg_int_lockinfo);
    ULI_PROBE("Pbs_pinpg_one_int", Pbs_pinpg_one_int_lockinfo);
    ULI_PROBE("Pbs_pinpg_found", Pbs_pinpg_found_lockinfo);
    ULI_PROBE("Pbs_pinpg_newpage", Pbs_pinpg_newpage_lockinfo);
    ULI_PROBE("Pbs_unpinpg", Pbs_unpinpg_lockinfo);
    ULI_PROBE("Pbs_find_page", Pbs_find_page_lockinfo);
    ULI_PROBE("P_state_block", P_state_block_lockinfo);
    ULI_PROBE("Pbs_set_bufstate", Pbs_set_bufstate_lockinfo);
    ULI_PROBE("Pbs_clear_bufstate", Pbs_clear_bufstate_lockinfo);
    ULI_PROBE("Pbs_get_bufstate", Pbs_get_bufstate_lockinfo);
    ULI_PROBE("Pset_state", Pset_state_lockinfo);
    ULI_PROBE("Pwait_state", Pwait_state_lockinfo);
    ULI_PROBE("Pclear_state", Pclear_state_lockinfo);
    ULI_PROBE("Pbuf_remap", Pbuf_remap_lockinfo);
    ULI_PROBE("Pseq_ahead_cont", Pseq_ahead_cont_lockinfo);
    ULI_PROBE("Pprefetch", Pprefetch_lockinfo);
    ULI_PROBE("Pseq_ahead_start", Pseq_ahead_start_lockinfo);
    ULI_PROBE("Pseq_ahead", Pseq_ahead_lockinfo);
    ULI_PROBE("Pbs_invalidate_pages", Pbs_invalidate_pages_lockinfo);
    ULI_PROBE("Pbfr_trace", Pbfr_trace_lockinfo);
    ULI_PROBE("Pbs_wakeup_flush_threads", Pbs_wakeup_flush_threads_lockinfo);

    /* bs/bs_copy.c probe stuff */
    ULI_PROBE("Pcp_copy_page_range", Pcp_copy_page_range_lockinfo);
    ULI_PROBE("Pset_block_map", Pset_block_map_lockinfo);
    ULI_PROBE("Pverify_page_write", Pverify_page_write_lockinfo);
    ULI_PROBE("Pforce_write", Pforce_write_lockinfo);
    ULI_PROBE("Pcompare_copies", Pcompare_copies_lockinfo);
    ULI_PROBE("Pcp_insert_onto_xtnt_ma", Pcp_insert_onto_xtnt_ma_lockinfo);
    ULI_PROBE("Pcp_remove_from_xtnt_ma", Pcp_remove_from_xtnt_ma_lockinfo);
    ULI_PROBE("Pcp_alloc_stg", Pcp_alloc_stg_lockinfo);

    /* bs/bs_create.c probe stuff */
    ULI_PROBE("Prbf_create", Prbf_create_lockinfo);
    ULI_PROBE("Prbf_int_create", Prbf_int_create_lockinfo);
    ULI_PROBE("Pcreate_rtdn_opx", Pcreate_rtdn_opx_lockinfo);
    ULI_PROBE("Pmake_mcell_valid", Pmake_mcell_valid_lockinfo);
    ULI_PROBE("Pcreate_undo_opx", Pcreate_undo_opx_lockinfo);
    ULI_PROBE("Pinit_bscreate_opx", Pinit_bscreate_opx_lockinfo);
    ULI_PROBE("Pnew_mcell", Pnew_mcell_lockinfo);
    ULI_PROBE("Pkill_mcell", Pkill_mcell_lockinfo);
    ULI_PROBE("Pdealloc_mcells", Pdealloc_mcells_lockinfo);

    /* bs/bs_delete.c probe stuff */
    ULI_PROBE("Pbs_deferred_delete_und", Pbs_deferred_delete_und_lockinfo);
    ULI_PROBE("Prbf_delete", Prbf_delete_lockinfo);
    ULI_PROBE("Prbf_delete_int", Prbf_delete_int_lockinfo);
    ULI_PROBE("Pbs_delete_undo_opx", Pbs_delete_undo_opx_lockinfo);
    ULI_PROBE("Preset_ondisk_bf_state", Preset_ondisk_bf_state_lockinfo);
    ULI_PROBE("Pbs_delete_rtdn_opx", Pbs_delete_rtdn_opx_lockinfo);
    ULI_PROBE("Pbs_delete", Pbs_delete_lockinfo);
    ULI_PROBE("Pinit_bs_delete_opx", Pinit_bs_delete_opx_lockinfo);
    ULI_PROBE("Pdel_add_to_del_list", Pdel_add_to_del_list_lockinfo);
    ULI_PROBE("Pdel_remove_from_del_li", Pdel_remove_from_del_li_lockinfo);
    ULI_PROBE("Pdel_bitfile_list_undo", Pdel_bitfile_list_undo_lockinfo);
    ULI_PROBE("Ppin_link", Ppin_link_lockinfo);
    ULI_PROBE("Ppin_hdr", Ppin_hdr_lockinfo);
    ULI_PROBE("Pdel_clean_mcell_list", Pdel_clean_mcell_list_lockinfo);
    ULI_PROBE("Pdel_dealloc_stg", Pdel_dealloc_stg_lockinfo);
    ULI_PROBE("Pdel_xtnt_array", Pdel_xtnt_array_lockinfo);
    ULI_PROBE("Pxfer_xtnts_to_clone", Pxfer_xtnts_to_clone_lockinfo);
    ULI_PROBE("Pdel_part_xtnt", Pdel_part_xtnt_lockinfo);
    ULI_PROBE("Pdel_range", Pdel_range_lockinfo);
    ULI_PROBE("Pdel_ftx_start", Pdel_ftx_start_lockinfo);
    ULI_PROBE("Pdel_ftx_done", Pdel_ftx_done_lockinfo);
    ULI_PROBE("Psbm_howmany_blks", Psbm_howmany_blks_lockinfo);
    ULI_PROBE("Pdel_find_del_entry", Pdel_find_del_entry_lockinfo);

    /* bs/bs_qio.c probe stuff */
    ULI_PROBE("Pcheck_queue", Pcheck_queue_lockinfo);
    ULI_PROBE("Pbs_q_blocking", Pbs_q_blocking_lockinfo);
    ULI_PROBE("Pbs_q_flushq", Pbs_q_flushq_lockinfo);
    ULI_PROBE("Pbs_q_list", Pbs_q_list_lockinfo);
    ULI_PROBE("Pbs_io_complete", Pbs_io_complete_lockinfo);
    ULI_PROBE("Pcheck_cont_bits", Pcheck_cont_bits_lockinfo);
    ULI_PROBE("Pbs_pinblock", Pbs_pinblock_lockinfo);
    ULI_PROBE("Pbs_pinblock_sync", Pbs_pinblock_sync_lockinfo);
    ULI_PROBE("Plsn_io_list", Plsn_io_list_lockinfo);
    ULI_PROBE("Pbs_lsnList_flush", Pbs_lsnList_flush_lockinfo);
    ULI_PROBE("Pbs_q_lazy", Pbs_q_lazy_lockinfo);
    ULI_PROBE("Pwait_to_readyq", Pwait_to_readyq_lockinfo);
    ULI_PROBE("Pready_to_consolq", Pready_to_consolq_lockinfo);
    ULI_PROBE("Psort_onto_readyq", Psort_onto_readyq_lockinfo);
    ULI_PROBE("Pcache_logflush", Pcache_logflush_lockinfo);
    ULI_PROBE("Pcall_logflush", Pcall_logflush_lockinfo);
    ULI_PROBE("Pbs_logpage_dirty", Pbs_logpage_dirty_lockinfo);
    ULI_PROBE("Pbs_logflush_start", Pbs_logflush_start_lockinfo);
    ULI_PROBE("Plogflush_cont", Plogflush_cont_lockinfo);
    ULI_PROBE("Pbfflush_start", Pbfflush_start_lockinfo);
    ULI_PROBE("Pbfflush_sync", Pbfflush_sync_lockinfo);
    ULI_PROBE("Pbfflush", Pbfflush_lockinfo);
    ULI_PROBE("Pbfflush_sync_nowait", Pbfflush_sync_nowait_lockinfo);
    ULI_PROBE("Pbs_bf_flush_nowait", Pbs_bf_flush_nowait_lockinfo);
    ULI_PROBE("Pbs_bflush", Pbs_bflush_lockinfo);
    ULI_PROBE("Pbs_bflush_sync", Pbs_bflush_sync_lockinfo);
    ULI_PROBE("Prm_from_lazyq", Prm_from_lazyq_lockinfo);
    ULI_PROBE("Plink_write_req", Plink_write_req_lockinfo);
    ULI_PROBE("Prm_ioq", Prm_ioq_lockinfo);
    ULI_PROBE("Pbs_raw_page", Pbs_raw_page_lockinfo);
    ULI_PROBE("Psendtoiothread", Psendtoiothread_lockinfo);
    ULI_PROBE("Pulmq_destroy_freelist", Pulmq_destroy_freelist_lockinfo);
    ULI_PROBE("Pmsgq_destroy", Pmsgq_destroy_lockinfo);
    ULI_PROBE("Pbs_io_rad_start", Pbs_io_rad_start_lockinfo);
    ULI_PROBE("Pmsfs_smoothsync", Pmsfs_smoothsync_lockinfo);
    ULI_PROBE("Padd_to_smsync", Padd_to_smsync_lockinfo);
    ULI_PROBE("Psmsync_to_readyq", Psmsync_to_readyq_lockinfo);

    /* bs/bs_tagdir.c probe stuff */
    ULI_PROBE("Ptagdir_get_info", Ptagdir_get_info_lockinfo);
    ULI_PROBE("Pinit_tagdir_opx", Pinit_tagdir_opx_lockinfo);
    ULI_PROBE("Ptagdir_remove_tag", Ptagdir_remove_tag_lockinfo);
    ULI_PROBE("Ptagdir_tag_to_freelist", Ptagdir_tag_to_freelist_lockinfo);
    ULI_PROBE("Ptagdir_freetag_dellist", Ptagdir_freetag_dellist_lockinfo);
    ULI_PROBE("Pinit_next_tag_page", Pinit_next_tag_page_lockinfo);
    ULI_PROBE("Ptagdir_alloc_tag", Ptagdir_alloc_tag_lockinfo);
    ULI_PROBE("Pextend_tagdir_redo_opx", Pextend_tagdir_redo_opx_lockinfo);
    ULI_PROBE("Ptagdir_insert_tag", Ptagdir_insert_tag_lockinfo);
    ULI_PROBE("Ptagdir_set_next_tag", Ptagdir_set_next_tag_lockinfo);
    ULI_PROBE("Ptagdir_reset_tagmap", Ptagdir_reset_tagmap_lockinfo);
    ULI_PROBE("Ptagdir_stuff_tagmap", Ptagdir_stuff_tagmap_lockinfo);
    ULI_PROBE("Ptagdir_set_tagmap_comm", Ptagdir_set_tagmap_comm_lockinfo);
    ULI_PROBE("Ptagdir_write_undo_opx", Ptagdir_write_undo_opx_lockinfo);
    ULI_PROBE("Ptagdir_lookup", Ptagdir_lookup_lockinfo);
    ULI_PROBE("Ptagdir_lookup2", Ptagdir_lookup2_lockinfo);
    ULI_PROBE("Ptagdir_lookup_next", Ptagdir_lookup_next_lockinfo);
    ULI_PROBE("Pbs_switch_root_tagdir", Pbs_switch_root_tagdir_lockinfo);
    ULI_PROBE("Pswitch_root_tagdir_red", Pswitch_root_tagdir_red_lockinfo);

    /* bs/bs_params probe stuff */
    ULI_PROBE("Pbs_get_bf_xtnt_map", Pbs_get_bf_xtnt_map_lockinfo);
    ULI_PROBE("Pbs_get_bkup_xtnt_map", Pbs_get_bkup_xtnt_map_lockinfo);
    ULI_PROBE("Pbs_get_clone_xtnt_map", Pbs_get_clone_xtnt_map_lockinfo);
    ULI_PROBE("Pbs_get_stripe_xtnt_map", Pbs_get_stripe_xtnt_map_lockinfo);
    ULI_PROBE("Pbs_get_bf_page_cnt", Pbs_get_bf_page_cnt_lockinfo);
    ULI_PROBE("Pbs_get_bf_params", Pbs_get_bf_params_lockinfo);
    ULI_PROBE("Pbs_set_bf_params", Pbs_set_bf_params_lockinfo);
    ULI_PROBE("Pbs_get_bf_iparams", Pbs_get_bf_iparams_lockinfo);
    ULI_PROBE("Pbs_set_bf_iparams", Pbs_set_bf_iparams_lockinfo);
    ULI_PROBE("Pbs_get_dmn_vd_list", Pbs_get_dmn_vd_list_lockinfo);
    ULI_PROBE("Pbs_get_dmn_params", Pbs_get_dmn_params_lockinfo);
    ULI_PROBE("Pbs_set_dmn_params", Pbs_set_dmn_params_lockinfo);
    ULI_PROBE("Pbs_get_vd_params", Pbs_get_vd_params_lockinfo);
    ULI_PROBE("Pbs_set_vd_params", Pbs_set_vd_params_lockinfo);
    ULI_PROBE("Pbs_get_avail_mcells", Pbs_get_avail_mcells_lockinfo);
    ULI_PROBE("Pbs_get_smsync_stats", Pbs_get_smsync_stats_lockinfo);

    /* bs/bs_service_class.c probe stuff */
    ULI_PROBE("Psc_init_sc_tbl", Psc_init_sc_tbl_lockinfo);
    ULI_PROBE("Psc_find_super_class", Psc_find_super_class_lockinfo);
    ULI_PROBE("Psc_find_alt_class", Psc_find_alt_class_lockinfo);
    ULI_PROBE("Psc_binSearchForClass", Psc_binSearchForClass_lockinfo);
    ULI_PROBE("Psc_add_class", Psc_add_class_lockinfo);
    ULI_PROBE("Psc_add_vd_to_class", Psc_add_vd_to_class_lockinfo);
    ULI_PROBE("Psc_add_vd", Psc_add_vd_lockinfo);
    ULI_PROBE("Psc_remove_class", Psc_remove_class_lockinfo);
    ULI_PROBE("Psc_remove_vd", Psc_remove_vd_lockinfo);
    ULI_PROBE("Psc_select_class", Psc_select_class_lockinfo);
    ULI_PROBE("Psc_valid_vd", Psc_valid_vd_lockinfo);
    ULI_PROBE("Psc_select_vd_for_mcell", Psc_select_vd_for_mcell_lockinfo);
    ULI_PROBE("Psc_select_vd_for_stg", Psc_select_vd_for_stg_lockinfo);

    /* bs/bs_stripe.c probe_stuff */
    ULI_PROBE("Pstr_register_stripe_ag", Pstr_register_stripe_ag_lockinfo);
    ULI_PROBE("Pbs_stripe", Pbs_stripe_lockinfo);
    ULI_PROBE("Pstr_stripe", Pstr_stripe_lockinfo);
    ULI_PROBE("Pstripe_zero_size", Pstripe_zero_size_lockinfo);
    ULI_PROBE("Pstripe_nonzero_size", Pstripe_nonzero_size_lockinfo);
    ULI_PROBE("Pundo_xtnt_rec", Pundo_xtnt_rec_lockinfo);
    ULI_PROBE("Pupdate_xtnt_rec_fields", Pupdate_xtnt_rec_fields_lockinfo);
    ULI_PROBE("Pstr_create_stripe_hdr", Pstr_create_stripe_hdr_lockinfo);
    ULI_PROBE("Pstr_delete_stripe_hdr", Pstr_delete_stripe_hdr_lockinfo);
    ULI_PROBE("Pstr_calc_page_alloc", Pstr_calc_page_alloc_lockinfo);
    ULI_PROBE("Pstr_create_bf_rel_xtnt", Pstr_create_bf_rel_xtnt_lockinfo);
    ULI_PROBE("Pcreate_bf_rel_xtnt_des", Pcreate_bf_rel_xtnt_des_lockinfo);

    /* bs/ftx_recovery.c probe stuff */
    ULI_PROBE("Pftx_bfmeta_rec_redo", Pftx_bfmeta_rec_redo_lockinfo);
    ULI_PROBE("Pftx_bfdata_rec_redo", Pftx_bfdata_rec_redo_lockinfo);
    ULI_PROBE("Pftx_bfdmn_recovery", Pftx_bfdmn_recovery_lockinfo);
    ULI_PROBE("Pftx_recovery_pass", Pftx_recovery_pass_lockinfo);
    ULI_PROBE("Pnum_of_log_recs", Pnum_of_log_recs_lockinfo);
    ULI_PROBE("Pftx_metameta_rec_redo", Pftx_metameta_rec_redo_lockinfo);
    ULI_PROBE("Pcfs_list", Pcfs_list_lockinfo);
    ULI_PROBE("Pcfs_check_for_pfs_commit", Pcfs_check_for_pfs_commit_lockinfo);
    ULI_PROBE("Pcfs_xid_free_memory", Pcfs_xid_free_memory_lockinfo);
    ULI_PROBE("Pcfs_xid_free_memory_int", Pcfs_xid_free_memory_int_lockinfo);

    /* msfs/bs/ftx_routines.c probe stuff */
    ULI_PROBE("Pftx_register_agent", Pftx_register_agent_lockinfo);
    ULI_PROBE("Pftx_register_agent_n", Pftx_register_agent_n_lockinfo);
    ULI_PROBE("Pftx_register_agent_n2", Pftx_register_agent_n2_lockinfo);
    ULI_PROBE("P_ftx_start_i", P_ftx_start_i_lockinfo);
    ULI_PROBE("Pnewftx", Pnewftx_lockinfo);
    ULI_PROBE("Pftx_done", Pftx_done_lockinfo);
    ULI_PROBE("Pftx_done_fs", Pftx_done_fs_lockinfo);
    ULI_PROBE("Pftx_done_n", Pftx_done_n_lockinfo);
    ULI_PROBE("Pftx_done_u", Pftx_done_u_lockinfo);
    ULI_PROBE("Pftx_done_urd", Pftx_done_urd_lockinfo);
    ULI_PROBE("Pftx_done_urdr", Pftx_done_urdr_lockinfo);
    ULI_PROBE("Pftx_quit", Pftx_quit_lockinfo);
    ULI_PROBE("Pftx_fail", Pftx_fail_lockinfo);
    ULI_PROBE("Pftx_fail_2", Pftx_fail_2_lockinfo);
    ULI_PROBE("Pftx_set_continuation", Pftx_set_continuation_lockinfo);
    ULI_PROBE("Pftx_special_done_mode", Pftx_special_done_mode_lockinfo);
    ULI_PROBE("Prbf_pinpg", Prbf_pinpg_lockinfo);
    ULI_PROBE("Prbf_deref_page", Prbf_deref_page_lockinfo);
    ULI_PROBE("Prbf_pin_record", Prbf_pin_record_lockinfo);
    ULI_PROBE("Paddone_undo", Paddone_undo_lockinfo);
    ULI_PROBE("Paddone_redo", Paddone_redo_lockinfo);
    ULI_PROBE("Paddone_rtdn", Paddone_rtdn_lockinfo);
    ULI_PROBE("Paddone_cont", Paddone_cont_lockinfo);
    ULI_PROBE("Paddone_recredo", Paddone_recredo_lockinfo);
    ULI_PROBE("Plog_donerec_nunpin", Plog_donerec_nunpin_lockinfo);
    ULI_PROBE("Pdo_ftx_continuations", Pdo_ftx_continuations_lockinfo);
    ULI_PROBE("Pget_perlvl_p", Pget_perlvl_p_lockinfo);
    ULI_PROBE("P_ftx_lock", P_ftx_lock_lockinfo);
    ULI_PROBE("P_ftx_add_lock", P_ftx_add_lock_lockinfo);
    ULI_PROBE("P_ftx_set_state", P_ftx_set_state_lockinfo);
    ULI_PROBE("Pftx_unlock", Pftx_unlock_lockinfo);
    ULI_PROBE("Prelease_ftx_locks", Prelease_ftx_locks_lockinfo);
    ULI_PROBE("Pget_ftx_id", Pget_ftx_id_lockinfo);
    ULI_PROBE("Pftx_init", Pftx_init_lockinfo);
    ULI_PROBE("Pftx_free", Pftx_free_lockinfo);
    ULI_PROBE("Pftx_init_recovery_loga", Pftx_init_recovery_loga_lockinfo);
    ULI_PROBE("Pftx_get_dirtybufla", Pftx_get_dirtybufla_lockinfo);
    ULI_PROBE("Pftx_set_oldestftxla", Pftx_set_oldestftxla_lockinfo);
    ULI_PROBE("Pftx_get_oldestftxla", Pftx_get_oldestftxla_lockinfo);
    ULI_PROBE("Pftx_set_firstla", Pftx_set_firstla_lockinfo);
    ULI_PROBE("Preset_oldest_lsn", Preset_oldest_lsn_lockinfo);

    /* msfs/osf/msfs_proplist.c probe stuff */
    ULI_PROBE("Pmsfs_pl_register_agnts", Pmsfs_pl_register_agnts_lockinfo);
    ULI_PROBE("Pmsfs_pl_init_cur", Pmsfs_pl_init_cur_lockinfo);
    ULI_PROBE("Pmsfs_pl_cur_to_pnt", Pmsfs_pl_cur_to_pnt_lockinfo);
    ULI_PROBE("Pmsfs_pl_deref_cur", Pmsfs_pl_deref_cur_lockinfo);
    ULI_PROBE("Pmsfs_pl_pin_cur", Pmsfs_pl_pin_cur_lockinfo);
    ULI_PROBE("Pmsfs_pl_seek_cur", Pmsfs_pl_seek_cur_lockinfo);
    ULI_PROBE("Pmsfs_pl_next_mc_cur", Pmsfs_pl_next_mc_cur_lockinfo);
    ULI_PROBE("Pmsfs_setproplist", Pmsfs_setproplist_lockinfo);
    ULI_PROBE("Pmsfs_setproplist_int", Pmsfs_setproplist_int_lockinfo);
    ULI_PROBE("Pmsfs_pl_set_entry", Pmsfs_pl_set_entry_lockinfo);
    ULI_PROBE("Pmsfs_pl_fill_hdr_image", Pmsfs_pl_fill_hdr_image_lockinfo);
    ULI_PROBE("Pmsfs_pl_findhead_setdata", Pmsfs_pl_findhead_setdata_lockinfo);
    ULI_PROBE("Pmsfs_getproplist", Pmsfs_getproplist_lockinfo);
    ULI_PROBE("Pmsfs_getproplist_int", Pmsfs_getproplist_int_lockinfo);
    ULI_PROBE("Pmsfs_pl_create_rec", Pmsfs_pl_create_rec_lockinfo);
    ULI_PROBE("Pmsfs_pl_get_entry", Pmsfs_pl_get_entry_lockinfo);
    ULI_PROBE("Pmsfs_pl_get_name", Pmsfs_pl_get_name_lockinfo);
    ULI_PROBE("Pmsfs_pl_get_data", Pmsfs_pl_get_data_lockinfo);
    ULI_PROBE("Pmsfs_delproplist", Pmsfs_delproplist_lockinfo);
    ULI_PROBE("Pmsfs_delproplist_int", Pmsfs_delproplist_int_v3_lockinfo);
    ULI_PROBE("Pmsfs_pl_del_root_done", Pmsfs_pl_del_root_done_lockinfo);
    ULI_PROBE("Pmsfs_pl_del_data_chain", Pmsfs_pl_del_data_chain_lockinfo);
    ULI_PROBE("Pmsfs_pl_unlink_mcells", Pmsfs_pl_unlink_mcells_lockinfo);

    ULI_PROBE("Pmsfs_pl_set_entry_v3", Pmsfs_pl_set_entry_v3_lockinfo);
    ULI_PROBE("Pmsfs_pl_fill_hdr_image_v3", Pmsfs_pl_fill_hdr_image_v3_lockinfo);
    ULI_PROBE("Pmsfs_pl_findhead_setdata_v3", Pmsfs_pl_findhead_setdata_v3_lockinfo);
    ULI_PROBE("Pmsfs_getproplist_int_v3", Pmsfs_getproplist_int_v3_lockinfo);
    ULI_PROBE("Pmsfs_pl_get_entry_v3", Pmsfs_pl_get_entry_v3_lockinfo);
    ULI_PROBE("Pmsfs_pl_get_name_v3", Pmsfs_pl_get_name_v3_lockinfo);
    ULI_PROBE("Pmsfs_pl_get_data_v3", Pmsfs_pl_get_data_v3_lockinfo);
    ULI_PROBE("Pmsfs_delproplist_int_v3", Pmsfs_delproplist_int_lockinfo);

	/* kernel/msfs/fs/fs_dir_lookup.c	*/

	ULI_PROBE("Pinsert_seq", Pinsert_seq_lockinfo);
	ULI_PROBE("Premove_dir_ent", Premove_dir_ent_lockinfo);
	ULI_PROBE("Premove_dots", Premove_dots_lockinfo);
	ULI_PROBE("Pseq_search", Pseq_search_lockinfo);
	ULI_PROBE("Premove_bf", Premove_bf_lockinfo);
	ULI_PROBE("Ptag_search", Ptag_search_lockinfo);
	ULI_PROBE("Premove_entry", Premove_entry_lockinfo);
	ULI_PROBE("Psetup_for_glom_dir_entries", Psetup_for_glom_dir_entries_lockinfo);
	ULI_PROBE("Pglom_dir_entries", Pglom_dir_entries_lockinfo);
	ULI_PROBE("Pdir_trunc_start", Pdir_trunc_start_lockinfo);
	ULI_PROBE("Pdir_trunc_finish", Pdir_trunc_finish_lockinfo);

        /* kernel/msfs/osf/msfs_vfsops.c */
        ULI_PROBE("Pmsfs_vptofh", Pmsfs_vptofh_lockinfo);
        ULI_PROBE("Padvfs_quotactl", Padvfs_quotactl_lockinfo);
        ULI_PROBE("Padvfs_quotactl_mp", Padvfs_quotactl_mp_lockinfo);
        ULI_PROBE("Padvfs_mountfs", Padvfs_mountfs_lockinfo);
        ULI_PROBE("Pmsfs_unmount", Pmsfs_unmount_lockinfo);
        ULI_PROBE("Pcheck_vd_sizes", Pcheck_vd_sizes_lockinfo);

        /* kernel/msfs/bs/bs_bitfile_sets.c */
        ULI_PROBE("Pbs_fragbf_thread", Pbs_fragbf_thread_lockinfo);
        ULI_PROBE("Pfrag_group_dealloc",Pfrag_group_dealloc_lockinfo);
        ULI_PROBE("Pfrag_group_init",Pfrag_group_init_lockinfo);
        ULI_PROBE("Pfrag_list_extend",Pfrag_list_extend_lockinfo);
        ULI_PROBE("Pbs_frag_alloc",Pbs_frag_alloc_lockinfo);
        ULI_PROBE("Pbs_frag_dealloc",Pbs_frag_dealloc_lockinfo);
        ULI_PROBE("Pbs_fragbf_open",Pbs_fragbf_open_lockinfo);
        ULI_PROBE("Pbs_fragbf_close",Pbs_fragbf_close_lockinfo);
        ULI_PROBE("Pbs_frag_mark_group_header_as_bad",Pbs_frag_mark_group_header_as_bad_lockinfo);
        ULI_PROBE("Pbs_bfs_init",Pbs_bfs_init_lockinfo);
        ULI_PROBE("Pbfs_lookup",Pbfs_lookup_lockinfo);
        ULI_PROBE("Pbs_bfs_flush",Pbs_bfs_flush_lockinfo);
        ULI_PROBE("Pbfs_invalidate",Pbfs_invalidate_lockinfo);
        ULI_PROBE("Pbfs_alloc",Pbfs_alloc_lockinfo);
        ULI_PROBE("Pbfs_dealloc",Pbfs_dealloc_lockinfo);
        ULI_PROBE("Pbs_bfs_remove_all",Pbs_bfs_remove_all_lockinfo);
        ULI_PROBE("Pbs_bfs_lookup_desc",Pbs_bfs_lookup_desc_lockinfo);
        ULI_PROBE("Pbfs_create",Pbfs_create_lockinfo);
        ULI_PROBE("Prbf_bfs_create",Prbf_bfs_create_lockinfo);
        ULI_PROBE("Pbfs_close",Pbfs_close_lockinfo);
        ULI_PROBE("Pbs_bfs_close",Pbs_bfs_close_lockinfo);
        ULI_PROBE("Pbfs_access",Pbfs_access_lockinfo);
        ULI_PROBE("Pbfs_open",Pbfs_open_lockinfo);
        ULI_PROBE("Pdelete_orig_set_tags",Pdelete_orig_set_tags_lockinfo);
        ULI_PROBE("Pdelete_clone_set_tags",Pdelete_clone_set_tags_lockinfo);
        ULI_PROBE("Pbfs_delete_pending_list_add",Pbfs_delete_pending_list_add_lockinfo);
        ULI_PROBE("Pdel_list_remove_undo",Pdel_list_remove_undo_lockinfo);
        ULI_PROBE("Pbfs_delete_pending_list_remove",Pbfs_delete_pending_list_remove_lockinfo);
        ULI_PROBE("Pbfs_delete_pending_list_finish_all",Pbfs_delete_pending_list_finish_all_lockinfo);
        ULI_PROBE("Punlink_clone_undo",Punlink_clone_undo_lockinfo);
        ULI_PROBE("Punlink_clone",Punlink_clone_lockinfo);
        ULI_PROBE("Pbs_bfs_delete",Pbs_bfs_delete_lockinfo);
        ULI_PROBE("Pclone_tagdir",Pclone_tagdir_lockinfo);
        ULI_PROBE("Pbs_bfs_clone",Pbs_bfs_clone_lockinfo);
        ULI_PROBE("Pbs_bf_out_of_sync",Pbs_bfs_out_of_sync_lockinfo);
        ULI_PROBE("Pbs_bfs_out_of_sync",Pbs_bfs_out_of_sync_lockinfo);
        ULI_PROBE("Pbs_bfs_get_set_id",Pbs_bfs_get_set_id_lockinfo);
        ULI_PROBE("Pbs_bfs_get_clone_info",Pbs_bfs_get_clone_info_lockinfo);
        ULI_PROBE("Pbs_bfs_add_root",Pbs_bfs_add_root_lockinfo);
        ULI_PROBE("Pbs_bfs_remove_root",Pbs_bfs_remove_root_lockinfo);
        ULI_PROBE("Pbs_bfs_switch_root_tagdir",Pbs_bfs_switch_root_tagdir_lockinfo);
        ULI_PROBE("Pbs_bfset_activate",Pbs_bfset_activate_lockinfo);
        ULI_PROBE("Pbs_bfset_deactivate",Pbs_bfset_deactivate_lockinfo);
        ULI_PROBE("Pbs_bfs_get_info",Pbs_bfs_get_info_lockinfo);
        ULI_PROBE("Pbs_bfs_find_set",Pbs_bfs_find_set_lockinfo);
        ULI_PROBE("Pnew_clone_mcell",Pnew_clone_mcell_lockinfo);
        ULI_PROBE("Pnew_clone_mcell_undo_opx",Pnew_clone_mcell_undo_opx_lockinfo);
        ULI_PROBE("Pinit_crmcell_opx",Pinit_crmcell_opx_lockinfo);
        ULI_PROBE("Pclone",Pclone_lockinfo);
        ULI_PROBE("Pbs_have_clone",Pbs_have_clone_lockinfo);
        ULI_PROBE("Pprint_out_of_sync_msg",Pprint_out_of_sync_msg_lockinfo);
        ULI_PROBE("Pbs_cow_pg",Pbs_cow_pg_lockinfo);
        ULI_PROBE("Pbs_cow",Pbs_cow_lockinfo);
        ULI_PROBE("Pbs_get_bfset_params",Pbs_get_bfset_params_lockinfo);
        ULI_PROBE("Pbs_set_bfset_params",Pbs_set_bfset_params_lockinfo);
        ULI_PROBE("Prbf_set_bfset_params",Prbf_set_bfset_params_lockinfo);

        /* kernel/msfs/bs/ms_logger.c */
	ULI_PROBE("Plgr_lsn_gt", Plgr_lsn_gt_lockinfo);
	ULI_PROBE("Plgr_lsn_lt", Plgr_lsn_lt_lockinfo);
	ULI_PROBE("Plsn_add", Plsn_add_lockinfo);
	ULI_PROBE("Plsn_gt", Plsn_gt_lockinfo);
	ULI_PROBE("Plsn_lt", Plsn_lt_lockinfo);
	ULI_PROBE("Plgr_make_pg_safe", Plgr_make_pg_safe_lockinfo);
	ULI_PROBE("Plgr_valid_blk", Plgr_valid_blk_lockinfo);
	ULI_PROBE("Plgr_repair_pg", Plgr_repair_pg_lockinfo);
	ULI_PROBE("Plgr_complete_pg", Plgr_complete_pg_lockinfo);
	ULI_PROBE("Plgr_restore_pg", Plgr_restore_pg_lockinfo);
	ULI_PROBE("Plgr_restore_rec", Plgr_restore_rec_lockinfo);
	ULI_PROBE("Plgr_valid_pg", Plgr_valid_pg_lockinfo);
	ULI_PROBE("Plgr_refpg", Plgr_refpg_lockinfo);
	ULI_PROBE("Plgr_unpinpg", Plgr_unpinpg_lockinfo);
	ULI_PROBE("Plgr_init", Plgr_init_lockinfo);
	ULI_PROBE("Padd_lsn_list", Padd_lsn_list_lockinfo);
	ULI_PROBE("Plgr_writev_ftx", Plgr_writev_ftx_lockinfo);
	ULI_PROBE("Pget_clean_pg", Pget_clean_pg_lockinfo);
	ULI_PROBE("Plgr_retest_firstrec", Plgr_retest_firstrec_lockinfo);
	ULI_PROBE("Presetfirstrec", Presetfirstrec_lockinfo);
	ULI_PROBE("PgetLogStats", PgetLogStats_lockinfo);
	ULI_PROBE("Prelease_dirty_pg", Prelease_dirty_pg_lockinfo);
	ULI_PROBE("Plgr_write", Plgr_write_lockinfo);
	ULI_PROBE("Plgr_read_open", Plgr_read_open_lockinfo);
	ULI_PROBE("Plgr_dmn_read_open", Plgr_dmn_read_open_lockinfo);
	ULI_PROBE("Plgr_read_close", Plgr_read_close_lockinfo);
	ULI_PROBE("Plgr_read", Plgr_read_lockinfo);
	ULI_PROBE("Pget_pg_lsn", Pget_pg_lsn_lockinfo);
	ULI_PROBE("Pfind_log_end_pg", Pfind_log_end_pg_lockinfo);
	ULI_PROBE("Psetup_log_desc", Psetup_log_desc_lockinfo);
	ULI_PROBE("Plog_init", Plog_init_lockinfo);
	ULI_PROBE("Plgr_open", Plgr_open_lockinfo);
	ULI_PROBE("Plgr_close", Plgr_close_lockinfo);
	ULI_PROBE("Plgr_flush", Plgr_flush_lockinfo);
	ULI_PROBE("Plgr_flush_start", Plgr_flush_start_lockinfo);
	ULI_PROBE("Plgr_flush_sync", Plgr_flush_sync_lockinfo);
	ULI_PROBE("Plog_flush", Plog_flush_lockinfo);
	ULI_PROBE("Plog_flush_sync", Plog_flush_sync_lockinfo);
	ULI_PROBE("Plgr_get_last_rec", Plgr_get_last_rec_lockinfo);
	ULI_PROBE("Plgr_dmn_get_last_rec", Plgr_dmn_get_last_rec_lockinfo);
	ULI_PROBE("Plgr_get_first_rec", Plgr_get_first_rec_lockinfo);
	ULI_PROBE("Plgr_dmn_get_first_rec", Plgr_dmn_get_first_rec_lockinfo);
	ULI_PROBE("Plgr_dmn_get_pseudo_first_rec", Plgr_dmn_get_pseudo_first_rec_lockinfo);
	ULI_PROBE("Plgr_checkpoint_log", Plgr_checkpoint_log_lockinfo);
	ULI_PROBE("Plgr_switch_vol", Plgr_switch_vol_lockinfo);
	ULI_PROBE("Plgr_calc_num_pgs", Plgr_calc_num_pgs_lockinfo);

	/* kernel/msfs/bs/bs_sbm.c */
	ULI_PROBE("Pbitmap_undo_opx", Pbitmap_undo_opx_lockinfo);
        ULI_PROBE("Pinit_bs_bitmap_opx", Pinit_bs_bitmap_opx_lockinfo);
	ULI_PROBE("Psbm_set_pg_bits", Psbm_set_pg_bits_lockinfo);
        ULI_PROBE("Palloc_bits", Palloc_bits_lockinfo);
	ULI_PROBE("Palloc_bits_page", Palloc_bits_page_lockinfo);
        ULI_PROBE("Pdealloc_bits_no_sub_ftx", Pdealloc_bits_no_sub_ftx_lockinfo);
	ULI_PROBE("Pdealloc_bits_page", Pdealloc_bits_page_lockinfo);
        ULI_PROBE("Psbm_find_space", Psbm_find_space_lockinfo);
	ULI_PROBE("Psbm_remove_space", Psbm_remove_space_lockinfo);
	ULI_PROBE("Psbm_return_space_no_sub_ftx", Psbm_return_space_no_sub_ftx_lockinfo);
	ULI_PROBE("Premove_desc", Premove_desc_lockinfo);
	ULI_PROBE("Padd_cache", Padd_cache_lockinfo);
	ULI_PROBE("Premove_cache", Premove_cache_lockinfo);
	ULI_PROBE("Pload_x_cache", Pload_x_cache_lockinfo);
	ULI_PROBE("Psbm_init", Psbm_init_lockinfo);
	ULI_PROBE("Psbm_clear_cache", Psbm_clear_cache_lockinfo);
	ULI_PROBE("Psbm_total_free_space", Psbm_total_free_space_lockinfo);
	ULI_PROBE("Psbm_dump", Psbm_dump_lockinfo);
	ULI_PROBE("Psbm_verify_xor", Psbm_verify_xor_lockinfo);

	/* kernel/msfs/bs/bs_stg.c */

	ULI_PROBE("Padd_stg_undo", Padd_stg_undo_lockinfo);
	ULI_PROBE("Premove_stg_undo", Premove_stg_undo_lockinfo);
	ULI_PROBE("Pinit_bs_stg_opx", Pinit_bs_stg_opx_lockinfo);
	ULI_PROBE("Prbf_add_overlapping_stg", Prbf_add_overlapping_stg_lockinfo);
	ULI_PROBE("Prbf_add_overlapping_clone_stg", Prbf_add_overlapping_clone_stg_lockinfo);
	ULI_PROBE("Prbf_add_stg", Prbf_add_stg_lockinfo);
	ULI_PROBE("Pstg_add_stg", Pstg_add_stg_lockinfo);
	ULI_PROBE("Pstg_add_stg_no_cow", Pstg_add_stg_no_cow_lockinfo);
	ULI_PROBE("Pstg_set_alloc_disk", Pstg_set_alloc_disk_lockinfo);
	ULI_PROBE("Padd_stg", Padd_stg_lockinfo);
	ULI_PROBE("Padd_rsvd_stg", Padd_rsvd_stg_lockinfo);
	ULI_PROBE("Palloc_stg", Palloc_stg_lockinfo);
	ULI_PROBE("Palloc_append_stg", Palloc_append_stg_lockinfo);
	ULI_PROBE("Pget_first_mcell", Pget_first_mcell_lockinfo);
	ULI_PROBE("Palloc_hole_stg", Palloc_hole_stg_lockinfo);
	ULI_PROBE("Pstg_alloc_from_svc_class", Pstg_alloc_from_svc_class_lockinfo);
	ULI_PROBE("Pcp_stg_alloc_from_svc_class", Pcp_stg_alloc_from_svc_class_lockinfo);
	ULI_PROBE("Pextend_skip", Pextend_skip_lockinfo);
	ULI_PROBE("Pstg_alloc_from_one_disk", Pstg_alloc_from_one_disk_lockinfo);
	ULI_PROBE("Pcp_stg_alloc_from_one_disk", Pcp_stg_alloc_from_one_disk_lockinfo);
	ULI_PROBE("Palloc_from_one_disk", Palloc_from_one_disk_lockinfo);
	ULI_PROBE("Pcp_stg_alloc_in_one_mcell", Pcp_stg_alloc_in_one_mcell_lockinfo);
	ULI_PROBE("Padd_extent", Padd_extent_lockinfo);
	ULI_PROBE("Pstg_alloc_one_xtnt", Pstg_alloc_one_xtnt_lockinfo);
	ULI_PROBE("Pxfer_stg", Pxfer_stg_lockinfo);
	ULI_PROBE("Pxfer_stg_to_bf", Pxfer_stg_to_bf_lockinfo);
	ULI_PROBE("Pxfer_stg_to_xtnts", Pxfer_stg_to_xtnts_lockinfo);
	ULI_PROBE("Pxfer_append_stg", Pxfer_append_stg_lockinfo);
	ULI_PROBE("Pxfer_hole_stg", Pxfer_hole_stg_lockinfo);
	ULI_PROBE("Pxfer_stg_on_one_disk", Pxfer_stg_on_one_disk_lockinfo);
	ULI_PROBE("Pxfer_stg_in_one_subxtnt", Pxfer_stg_in_one_subxtnt_lockinfo);
	ULI_PROBE("Pstg_alloc_new_mcell", Pstg_alloc_new_mcell_lockinfo);
	ULI_PROBE("Pmake_perm_hole", Pmake_perm_hole_lockinfo);
	ULI_PROBE("Pappend_perm_hole", Pappend_perm_hole_lockinfo);
	ULI_PROBE("Pinsert_perm_hole", Pinsert_perm_hole_lockinfo);
	ULI_PROBE("Padd_hole_extent", Padd_hole_extent_lockinfo);
	ULI_PROBE("Pnew_sub", Pnew_sub_lockinfo);
	ULI_PROBE("Px_page_to_iolist", Px_page_to_iolist_lockinfo);
	ULI_PROBE("Px_page_to_blkmap", Px_page_to_blkmap_lockinfo);
	ULI_PROBE("Px_copypage_to_blkmap", Px_copypage_to_blkmap_lockinfo);
	ULI_PROBE("Pscan_xtnt_map_list", Pscan_xtnt_map_list_lockinfo);
	ULI_PROBE("Px_page_to_blk", Px_page_to_blk_lockinfo);
	ULI_PROBE("Ppage_is_mapped", Ppage_is_mapped_lockinfo);
	ULI_PROBE("Pstg_remove_stg_start", Pstg_remove_stg_start_lockinfo);
	ULI_PROBE("Pstg_remove_stg_finish", Pstg_remove_stg_finish_lockinfo);
	ULI_PROBE("Premove_stg", Premove_stg_lockinfo);
	ULI_PROBE("Pdealloc_stg", Pdealloc_stg_lockinfo);
	ULI_PROBE("Pclip_del_xtnt_map", Pclip_del_xtnt_map_lockinfo);
	ULI_PROBE("Pmerge_xtnt_maps", Pmerge_xtnt_maps_lockinfo);
	ULI_PROBE("Pmerge_sub_xtnt_maps", Pmerge_sub_xtnt_maps_lockinfo);
	ULI_PROBE("Punload_sub_xtnt_maps", Punload_sub_xtnt_maps_lockinfo);
	ULI_PROBE("Pstg_add_rbmt_stg", Pstg_add_rbmt_stg_lockinfo);

	/* kernel/msfs/osf/msfs_io.c */
	ULI_PROBE("Pdomain_panic", Pdomain_panic_lockinfo);
	ULI_PROBE("Pbs_osf_complete", Pbs_osf_complete_lockinfo);
	ULI_PROBE("Pmsfs_iodone", Pmsfs_iodone_lockinfo);
	ULI_PROBE("Pmsfs_async_iodone_lwc", Pmsfs_async_iodone_lwc_lockinfo);
	ULI_PROBE("Pcheck_consol_list", Pcheck_consol_list_lockinfo);
	ULI_PROBE("Plist_map", Plist_map_lockinfo);
	ULI_PROBE("Pconsecutive_list_io", Pconsecutive_list_io_lockinfo);
	ULI_PROBE("Pcall_disk", Pcall_disk_lockinfo);
	ULI_PROBE("Pbs_startio", Pbs_startio_lockinfo);
	ULI_PROBE("Pread_raw_page", Pread_raw_page_lockinfo);
	ULI_PROBE("Pwrite_raw_page", Pwrite_raw_page_lockinfo);

	/* kernel/msfs/osf/msfs_lookup.c */
	ULI_PROBE("Pstrtoul", Pstrtoul_lockinfo);
	ULI_PROBE("Pmsfs_lookup", Pmsfs_lookup_lockinfo);
	ULI_PROBE("Pcheck_path_back", Pcheck_path_back_lockinfo);
	ULI_PROBE("Pnew_parent", Pnew_parent_lockinfo);

	/* kernel/msfs/osf/msfs_syscalls.c */
	ULI_PROBE("Pmsfs_syscall", Pmsfs_syscall_lockinfo);

#endif /* MSFS */

	/********************************************/
	/* start of lockinfo specs for simple locks */
	/********************************************/

#ifdef	TNC_CFE
	TNCLI(msg_lkdata);		/* PLMIN(1), 150 */
	TNCLI(msg_outq_lkdata);
	TNCLI(msg_free_lkdata);
	TNCLI(msg_free_idlist_lkdata);
	ULI("cfs_rec_vlimit_lock", cfs_rec_vlimit_lockinfo, SPLNONE, DEFAULT);
	ULI("blkrsrv_mutex_lock", br_mutex_lkdata, SPLNONE, DEFAULT);
	ULI("blkrsrv_condlock", br_condlock_lkdata, SPLNONE, DEFAULT);
	ULI("blkrsrv_dmn_data_lock", bd_dmn_data_lkdata, SPLNONE, DEFAULT);
	ULI("cfstok_freelist_lock", cfstok_freelist_lkdata, SPLNONE, DEFAULT);
	TNCLI(dr_list_lkdata);		/* PLTIMEOUT(1), CFS_HIERXXXX(150) */



	SLI("cfs_semaphores", cfs_semaphore_info, SPLNONE, DEFAULT);
	ULI("cnodehash_lock", cnodehash_lockinfo, SPLNONE, DEFAULT);
	ULI("cfs_mounting", cfs_mounting_lockinfo, SPLNONE, DEFAULT);
	ULI("cfs_mntinfo.mi_lock", cmi_lock_lockinfo, SPLNONE, DEFAULT);
	ULI("cnode.c_statelock", c_statelock_lockinfo, SPLNONE, DEFAULT);
        ULI("svrtok_hash_lock", svrtok_hash_lockinfo, SPLNONE,DEFAULT);
        ULI("svrcfstok.sct_statelock", sct_statelock_lockinfo, SPLNONE,DEFAULT);
	ULI("cfs_async_lock", cfs_async_lockinfo, SPLNONE, DEFAULT);
#endif	/* TNC_CFE */

#if	ICS_LL_MCT > 0
        /* ICS MCT spin lock used for HL/LL interface */
        SLI("ics_mct_llif_lock", ics_mct_llif_lockinfo,   SPLNONE, DEFAULT);
#endif
#if	ICS_HL > 0
	/* Low-level ICS spin locks. Must be above the high-level ICS locks. */
	TNCLI(icsmsg_arr_lock_lkdata);

	/* High-level ICS spin locks. Could all be at same priority. */
        TNCLI(icsservice_lock_lkdata);
        TNCLI(icssvc_node_lock_lkdata);
	TNCLI(ics_nodestatus_lock_lkdata);
	TNCLI(icsstat_lock_lkdata);
	TNCLI(clihand_list_lkdata);
        TNCLI(clihand_cache_list_lkdata);
	TNCLI(icscli_throttle_lock_lkdata);
	TNCLI(icssvr_mgmt_lock_lkdata);
	TNCLI(svrhand_wait_list_lock_lkdata);
	TNCLI(svrhand_nomem_list_lock_lkdata);
	TNCLI(svrhand_list_lkdata);
#endif	/* ICS_HL > 0 */

#if	ICS_LL_TCP > 0
	/* Low-level ICS TCP spin locks. Could all be at same priority. */
	TNCLI(ics_llnodedown_list_lkdata);
	TNCLI(ics_llnodeinfo_lkdata);
	/* Low-level ICS spin locks. Must be below the high-level ICS locks. */
	TNCLI(icsllhand_lkdata);
#endif	/* ICS_LL_TCP > 0 */

#if	ICS_LL_MCT > 0
        /* Low-level ICS MCT spin locks */
	SLI("ics_mct_ooltest_lock", ics_mct_ooltest_lock_i, SPLNONE, DEFAULT);
        SLI("ics_mct_llmanage_lock",
                                ics_mct_llmanage_lockinfo,   SPLNONE, DEFAULT);
        SLI("ics_mct_endpt_nosndq_lk",
                                ics_mct_endpt_nosndq_lkinfo, SPLNONE, DEFAULT);
        SLI("ics_mct_endpt_noackq_lk",
                                ics_mct_endpt_noackq_lkinfo, SPLNONE, DEFAULT);
        SLI("ics_mct_llrail_lock",
                                ics_mct_llrail_lockinfo,     SPLNONE, DEFAULT);
        SLI("ics_mct_llhandle_lock",
                                ics_mct_llhandle_lockinfo,   SPLNONE, DEFAULT);

	SLI("ics_mct_oolctl_lock", ics_mct_oolctl_lock_i, SPLNONE, DEFAULT);
	SLI("ics_mct_rail_lock", ics_mct_rail_lock_i, SPLNONE, DEFAULT);
	SLI("ics_mct_stage_lock", ics_mct_stage_lock_i, SPLNONE, DEFAULT);
	SLI("ics_mct_node_lock", ics_mct_node_lock_i, SPLNONE, DEFAULT);
	SLI("ics_mct_dropack_lock", ics_mct_dropack_lock_i, SPLNONE, DEFAULT);
	SLI("ics_mct_bucket_lock", ics_mct_bucket_lock_i, SPLNONE, DEFAULT);
#endif  /* ICS_LL_MCT */

#if DLM > 0
        ULI("dlm_pdb_lock",         dlm_pdb_lockinfo,         SPLNONE,DEFAULT);
        ULI("dlm_lkid_lock",        dlm_lkid_lockinfo,        SPLNONE,DEFAULT);
        ULI("dlm_lkb_lock",         dlm_lkb_lockinfo,         SPLNONE,DEFAULT);
        ULI("dlm_rsb_lock",         dlm_rsb_lockinfo,         SPLNONE,DEFAULT);
        ULI("dlm_rsb_incarn_lock",  dlm_rsb_incarn_lockinfo,  SPLNONE,DEFAULT);
        ULI("dlm_rhash_chain_lock", dlm_rhash_chain_lockinfo, SPLNONE,DEFAULT);
        ULI("dlm_rsbinfo_respq_lock",dlm_rsbinfo_respq_lockinfo,SPLNONE,DEFAULT);
        ULI("dlm_msg_respq_lock",   dlm_msg_respq_lockinfo,   SPLNONE,DEFAULT);
        ULI("dlm_deadlockq_lock",   dlm_deadlockq_lockinfo,   SPLNONE,DEFAULT);
        ULI("dlm_timeoutq_lock",    dlm_timeoutq_lockinfo,    SPLNONE,DEFAULT);
#endif /* DLM */
#if KCH > 0
	ULI("kch_set_tbl_lock", kch_set_tbl_lockinfo, SPLNONE, DEFAULT);
	ULI("kch_set_lock", kch_set_lockinfo, SPLNONE, DEFAULT);
	ULI("kch_mbrs_lock", kch_mbrs_lockinfo, SPLNONE, DEFAULT);
	ULI("kch_lstnrs_lock", kch_lstnrs_lockinfo, SPLNONE, DEFAULT);
	ULI("kch_obj_tbl_lock", obj_tbl_lockinfo, SPLNONE, DEFAULT);
	ULI("kch_wipq_lock", kch_wipq_lockinfo, SPLNONE, DEFAULT);
#endif /* KCH */

	SLI("rad.rad_task_fl_lock", rad_task_fl_lockinfo, SPLNONE, DEFAULT);
	SLI("rad.rad_processor_queue_lock", rad_processor_queue_lockinfo, SPLNONE, DEFAULT);
	ULI("hostname_lock", hostname_lockinfo, SPLNONE, RWS);
	NLI("ifnet_spin_lock", ifnet_spin_li, SPLNONE, DEFAULT);
	NLI("inifaddr_spin_lock", inifaddr_spin_li, SPLNONE, RWS);
	NLI("radix_mask_spin_lock", radix_mask_spin_li, SPLNONE, DEFAULT);
	NLI("ifqueue.ifq_slock_splnone", ifqueue_splnone_li, SPLNONE, DEFAULT);
	NLI("domain.dom_rc_lock", dom_rc_li, SPLNONE, DEFAULT);
	NLI("aggport_list_lock", aggport_list_li, SPLNONE, DEFAULT);
#if UIPC > 0
	NLI("global_unpconn_lock", global_unpconn_li, SPLNONE, DEFAULT);
#endif
	NLI("in6_ifnet_lock", in6_ifnet_li, SPLNONE, DEFAULT);
	NLI("in6_localaddr_lock", in6_localaddr_li, SPLNONE, RWS);
	NLI("in6_ifaddr_lock", in6_ifaddr_li, SPLNONE, DEFAULT);
	NLI("in6_randomseed_lock", in6_randomseed_li, SPLNONE, DEFAULT);
	NLI("icmp6_tx_errlog_lock", icmp6_tx_errlog_li, SPLNONE, DEFAULT);
#if NFS
	ULI("cku_data_lock", cku_data_lock_info, SPLNONE, DEFAULT);
#endif /* NFS */
	ULI("lk_rpcrqcred", lk_rpcrqcred_info, SPLNONE, DEFAULT);
	ULI("lk_rpccallout", lk_rpccallout_info, SPLNONE, DEFAULT);
	ULI("lk_rpcdupreq", lk_rpcdupreq_info, SPLNONE, DEFAULT);

#if AUTOFS > 0
	ULI("autofs_lock", autofs_lockinfo, SPLNONE, DEFAULT);
	ULI("anodehash_lock", anodehash_lockinfo, SPLNONE, DEFAULT);
	ULI("autofs_node_lock", autofs_node_lockinfo, SPLNONE, DEFAULT);
#endif
	ULI("nfs_activewrites_lock",nfs_activewrites_lockinfo,SPLNONE,DEFAULT);
	ULI("nfs_writefree_lock", nfs_writefree_lockinfo, SPLNONE, DEFAULT);
	ULI("nfs_sys_lock", nfs_sys_lockinfo, SPLNONE, DEFAULT);
	ULI("tslist_lock", nfs_tslist_lockinfo, SPLNONE, DEFAULT);
	ULI("chlist_lock", chlist_lockinfo, SPLNONE, DEFAULT);
	ULI("asyncdaemon_lock", asyncdaemon_lockinfo, SPLNONE, DEFAULT);
	ULI("nfs_newnum_lock", nfs_newnum_lockinfo, SPLNONE, DEFAULT);
	ULI("rtable.rn_lock", rnodehash_lockinfo, SPLNONE, DEFAULT);
	ULI("rnode.r_statelock", rnode_state_lockinfo, SPLNONE, DEFAULT);
	ULI("mntinfo.mi_lock", mntinfo_lockinfo, SPLNONE, DEFAULT);
	ULI("klm_misc", klm_misc_lockinfo, SPLNONE, DEFAULT);

	SLI("shm_stats_lock", shm_stats_lockinfo, SPLNONE, DEFAULT);
	SLI("shmid_lock", shmid_lockinfo, SPLNONE, DEFAULT);
	SLI("msgid_lock", msgid_lockinfo, SPLNONE, DEFAULT);
	SLI("semid_lock", semid_lockinfo, SPLNONE, DEFAULT);
	SLI("undo_lock", undo_lockinfo, SPLNONE, DEFAULT);
	SLI("cur_msghdrs", cur_msghdrs_lockinfo, SPLNONE, DEFAULT);
	SLI("vm_stack_queue_lock", vm_stack_queue_lockinfo, SPLNONE, DEFAULT);
	SLI("all_psets_lock", all_psets_lockinfo, SPLNONE, DEFAULT);
	SLI("all_nsgs_lock", all_nsgs_lockinfo, SPLNONE, DEFAULT);
	SLI("nsg_member_lock", nsg_member_lockinfo, SPLNONE, ORDERED);

	ULI("accounting_lock", accounting_lockinfo, SPLNONE, DEFAULT);
	ULI("aiosb_lock", aiosb_lockinfo, SPLNONE, DEFAULT);
	ULI("gidhash.ht_lock", gidhash_lockinfo, SPLNONE, ORDERED);
	ULI("uidhash.ht_lock", uidhash_lockinfo, SPLNONE, ORDERED);
	ULI("pidtab.pe_lock", pid_entry_lockinfo, SPLNONE, DEFAULT);
	ULI("proc.p_lock", proc_lockinfo, SPLNONE, ORDERED);
	ULI("pid_free_lock", pid_free_lockinfo, SPLNONE, DEFAULT);
	ULI("nofault_lock", nofault_lockinfo, SPLNONE, DEFAULT);
	ULI("session.s_lock", sess_lockinfo, SPLNONE, DEFAULT);

	SLI("task.lock", task_lockinfo, SPLNONE, ORDERED);
	SLI("nmr_lock", nmr_lockinfo, SPLNONE, DEFAULT);
	SLI("swap_control.sc_qlock",task_swap_lockinfo,SPLNONE,ORDERED);
	SLI("processor_set.lock", pset_lockinfo, SPLNONE, ORDERED);
	SLI("pag.lock", pag_lockinfo, SPLNONE, ORDERED);
	ULI("ruidhash.ht_lock", ruidhash_lockinfo, SPLNONE, ORDERED);
	SLI("task.ipc_translation_lock", ipc_task_lockinfo, SPLNONE, DEFAULT);
	SLI("thread.ipc_state_lock", ipc_thread_lockinfo, SPLNONE, DEFAULT);
	SLI("nxm_vp_lock", nxm_vp_lockinfo, SPLNONE, DEFAULT);
	SLI("nxm_thread_lock", nxm_thread_lockinfo, SPLNONE, DEFAULT);
	SLI("kern_port.port_data_lock", kern_port_lockinfo, SPLNONE, DEFAULT);
	SLI("kern_set.set_data_lock", kern_set_lockinfo, SPLNONE, ORDERED);
	SLI("msg_queue.lock", msg_queue_lockinfo, SPLNONE, ORDERED);
	SLI("port_hash_bucket.lock", port_hash_lockinfo, SPLNONE, DEFAULT);
	SLI("reply_port_cache_lock", reply_pcache_lockinfo, SPLNONE, DEFAULT);
#if PROCFS > 0
	SLI("procfs_trace_lock", procfs_trace_lockinfo, SPLNONE, DEFAULT);
#endif

	ULI("kiorequest.req_lk", kio_reqs_lk_info, SPLNONE, DEFAULT);
	ULI("kio_sys_lk", kio_sys_lockinfo, SPLNONE, DEFAULT);
	ULI("kiohandle.kio_handle_lk", kio_handles_lk_info, SPLNONE, DEFAULT);
#if MSFS > 0
	/********************************************************
	 * AdvFS simple locks in the hierarchy
	 ********************************************************/
	ULI("DmnTblMutex", ADVDmnTblMutex_lockinfo, SPLNONE, DEFAULT );
	ULI("DomainMutex", ADVdomainT_mutex_lockinfo, SPLNONE, DEFAULT );
	ULI("LookupMutex", ADVLookupMutex_lockinfo, SPLNONE, DEFAULT );
	ULI("DomainHashChainLock",ADVDomainHashChainLock_lockinfo,SPLNONE,DEFAULT);
	ULI("BfSetHashChainLock",ADVBfSetHashChainLock_lockinfo,SPLNONE,DEFAULT);

    /* The next 6 locks replace the now-defunct IoQueueMutex */
    ULI("vdT.vdIoLock",       ADVvdT_vdIoLock_info,          SPLNONE, DEFAULT );
    ULI("bsBuf.bufLock",      ADVbufLock_lockinfo,           SPLNONE, DEFAULT );
    ULI("domainT.lsnLock",    ADVdomainT_lsnLock_lockinfo,   SPLNONE, DEFAULT );
    ULI("bfAccessT.bfIoLock", ADVBfAccessbfIoLock_lockinfo,  SPLNONE, DEFAULT );

    ULI("BfAccessHashChainLock",ADVBfAccessHashChainLock_lockinfo,SPLNONE,DEFAULT);
    ULI("bfsetT.accessChainLock", ADVbfSetT_accessChainLock_lockinfo, SPLNONE, DEFAULT );
    ULI("bfAccessT.bfaLock", ADVBfAccessbfaLock_lockinfo, SPLNONE, ORDERED );
    ULI("BfAccessFreeLock", ADVBfAccessFreeLock_lockinfo, SPLNONE, DEFAULT );
    ULI("LockMgrMutex.mutex",  msfs_lockmgrmutex_lockinfo, SPLNONE, DEFAULT );
    ULI("mutexT.mutex",  msfs_mp_mutex_lockinfo, SPLNONE, DEFAULT );
    ULI("filesetMutex", ADVfilesetMutex_lockinfo, SPLNONE, DEFAULT );
    ULI("fsContext_mutex", ADVfsContext_mutex_lockinfo, SPLNONE, DEFAULT );
    ULI("setMutex", ADVbfSetT_setMutex_lockinfo, SPLNONE, DEFAULT );
    ULI("bfSetT.setMutex", ADVbfSetT_setMutex_lockinfo, SPLNONE, DEFAULT );
    ULI("bfSetT.cloneDelStateMutex", ADVbfSetT_cloneDelStateMutex_lockinfo, SPLNONE, DEFAULT );
    ULI("FtxMutex", ADVFtxMutex_lockinfo, SPLNONE, DEFAULT );
    ULI("msgQT.mutex", ADVmsgQT_mutex_lockinfo, SPLNONE, DEFAULT );
    ULI("dqhash_chain_lock",ADVdqhash_chain_lockinfo,SPLNONE,DEFAULT);

    ULI("domainT.vdpTblLock", ADVdomainT_vdpTbl_lockinfo,   SPLNONE, DEFAULT );
    ULI("vdT.vdStateLock",    ADVvdT_vdStateLock_info,      SPLNONE, DEFAULT );
    ULI("bfAccessT.actRangeLock", ADVBfactRangeLock_info,   SPLNONE, DEFAULT );
    ULI("rangeFlushT.rangeFlushLock", ADVRangeFlushLock_info,SPLNONE, DEFAULT );
    ULI("bfSetT.bfSetMutex", ADVbfSetT_bfSetMutex_lockinfo, SPLNONE, DEFAULT );
#endif

#if IPSEC
	ULI("sshicept_selq_lock", sshicept_selq_lockinfo, SPLNET, DEFAULT);
        ULI("interceptor_lock", interceptor_lockinfo, SPLNONE, DEFAULT);
        ULI("ssh_timeout_queue_lock", ssh_timeout_queue_lockinfo, SPLNONE, DEFAULT);
#endif
	ULI("presto_lock", presto_lockinfo, SPLNONE, DEFAULT);
	ULI("ufile_state.uf_ofile_lock", ufd_lockinfo, SPLNONE, DEFAULT);
	ULI("ufile_entry.ufe_ofile_lock", ufe_lockinfo, SPLNONE, DEFAULT);
	ULI("utask_nd.utnd_lock", utnd_lockinfo, SPLNONE, DEFAULT);
	ULI("ihash_lock", ihash_lockinfo, SPLNONE, DEFAULT);
	ULI("inode.i_incore_lock", i_incore_lockinfo, SPLNONE, ORDERED);
	ULI("utask.uu_handy_lock", u_handy_lockinfo, SPLNONE, DEFAULT);
	ULI("file.f_incore_lock", file_lockinfo, SPLNONE, DEFAULT);
	ULI("vnode.v_lock", vnode_lockinfo, SPLNONE, DEFAULT);
	ULI("vn_free_lock", vn_free_lockinfo, SPLNONE, DEFAULT);
	ULI("nc_purge_lockinfo", nc_purge_lockinfo, SPLNONE, DEFAULT);
	ULI("gnnhash.gnnch_lockinfo", gnnch_lockinfo, SPLNONE, DEFAULT);
	ULI("nnhtable.nnh_lock", nnhash_lockinfo, SPLNONE, DEFAULT);

        SLI("ksm_cache_lock", ksm_cache_lockinfo, SPLNONE, ORDERED);
        SLI("ksm_lock", ksm_lockinfo, SPLNONE, ORDERED);
        SLI("hwc_lock", hwc_lockinfo, SPLNONE, DEFAULT);

#if CMS > 0
	ULI("advfs_domain.ad_attr_que_lock", ad_attr_que_lock_lockinfo,
		SPLNONE, DEFAULT);
	ULI("cms_bdev_list_lock", cms_bdev_list_lockinfo, SPLNONE, DEFAULT);
	ULI("cms_kgs_lock", cms_kgs_lockinfo, SPLNONE, DEFAULT);
	ULI("cfs_kgs_lock", cfs_kgs_lockinfo, SPLNONE, DEFAULT);
	ULI("cfs_kgs_info.cki_lock", cki_lock_lockinfo, SPLNONE, DEFAULT);
	ULI("cfs_kgs_info_list", cfs_kgs_info_list_lock, SPLNONE, DEFAULT) ;
	ULI("cms_join_list_lock", cms_join_list_lockinfo, SPLNONE, DEFAULT);
	ULI("cms_kgs_info_lock", cms_kgs_info_lockinfo, SPLNONE, DEFAULT);
	ULI("cfs_kgs_hash_table.cki_hash_lock", cfs_kgs_hash_lockinfo,
		SPLNONE, DEFAULT);
#endif

	NLI("tcb.inp_rc_lock", inp_tcp_rc_li, SPLNONE, DEFAULT);
	NLI("udb.inp_rc_lock", inp_udp_rc_li, SPLNONE, DEFAULT);
	NLI("rawip6pcb.inp_rc_lock", inp_rawip6_rc_li, SPLNONE, DEFAULT);
	NLI("mfclencap_lock", mfclencap_li, SPLNONE, DEFAULT);
	NLI("rtstat.rts_lock", rtstat_li, SPLNONE, DEFAULT);
	NLI("icmpstat.icps_lock", icmpstat_li, SPLNONE, DEFAULT);
	NLI("igmpstat.igps_lock", igmpstat_li, SPLNONE, DEFAULT);
	NLI("mrtstat.mrts_lock", mrtstat_li, SPLNONE, DEFAULT);
	NLI("ipstat.ips_lock", ipstat_li, SPLNONE, DEFAULT);
#if LOCK_NETSTATS
	NLI("icmp6stat.icmp6s_lock", icmp6stat_li, SPLNONE, DEFAULT);
	NLI("ip6stat.ips_lock", ip6stat_li, SPLNONE, DEFAULT);
#endif
	NLI("misc_tcp_lock", misc_tcp_li, SPLNONE, DEFAULT);
#if LOCK_NETSTATS
	NLI("tcpstat.tcps_lock", tcpstat_li, SPLNONE, DEFAULT);
	NLI("udpstat.udps_lock", udpstat_li, SPLNONE, DEFAULT);
#endif
#if NPTY > 0
	ULI("pty_lock", pty_lockinfo, SPLNONE, DEFAULT);
#endif
#if RPTY > 0
	SLI("pty_lock", pty_lockinfo, SPLNONE, DEFAULT);
#endif
#if DEC_AUDIT > 0
	ULI("audlog.lock", audlog_lockinfo, SPLNONE, DEFAULT);
	ULI("audselq.lock", audselq_lockinfo, SPLNONE, DEFAULT);
	ULI("audbuf.lock", audbuf_lockinfo, SPLNONE, DEFAULT);
	ULI("audmask.lock", audmask_lockinfo, SPLNONE, DEFAULT);
#endif

        ULI("dyn_hashtable_msgq_lock",DYNmsgq_lockinfo,SPLNONE, DEFAULT);

	SLI("consvp_lock", consvp_lockinfo, SPLNONE, DEFAULT);
	SLI("vm_map.ref_lock", vm_map_ref_lockinfo, SPLNONE, DEFAULT);
	SLI("vm_map_entry.vme_faultlock", vme_fault_lockinfo, SPLNONE, DEFAULT);
	SLI("pmap_seg_map.psm_lock", pmap_seg_map_lockinfo, SPLNONE, DEFAULT);
	SLI("vm_vp_object.vu_seglock", vop_seglockinfo, SPLNONE, DEFAULT);
	SLI("vm_object.ob_lock", vm_object_lockinfo, SPLNONE, ORDERED);

	SLI("pshared_state", pshared_state_lockinfo, SPLNONE, DEFAULT);
	SLI("pshared_object", pshared_object_lockinfo, SPLNONE, ORDERED);

	SLI("vm_map.hint_lock", vm_map_hint_lockinfo, SPLNONE, DEFAULT);
#ifdef	MESL_RNG	/* used only if ! MESL_USE_PCC */
	SLI("mesl_rng_lock", mesl_rng_lkinfo, SPLNONE, DEFAULT);
#endif	/* MESL_RNG */
	SLI("gr_mapping_lock", mapping_lock_lockinfo, SPLNONE, DEFAULT);
	SLI("gh_mad.gm_zeroer_lock", gm_zeroer_lockinfo, SPLNONE, DEFAULT);
	SLI("gh_mad.gm_collect_lock", gm_collect_lockinfo, SPLNONE, DEFAULT);
	SLI("gh_mad.gm_lock", gm_lockinfo, SPLNONE, DEFAULT);
#if RMVM > 0
	SLI("vm_rm_object.links_lock", vm_rm_object_links_lockinfo, SPLNONE, ORDERED);
	SLI("rm_object_map_recv_lock",rm_object_map_recv_lockinfo, SPLNONE, DEFAULT); 
	SLI("rm_object_map_trans_base_lock",rm_object_map_trans_base_lockinfo, SPLNONE, DEFAULT);
	SLI("rm_object_map_dual_base_lock",rm_object_map_dual_base_lockinfo, SPLNONE, DEFAULT);
	SLI("vm_rm_object.ob_lock", vm_rm_object_lockinfo, SPLNONE, DEFAULT);
#endif
	SLI("shared_segment.ss_lock", shared_segment_lockinfo, SPLNONE,DEFAULT);
	SLI("vm_swap_circular_lock", vm_swap_circular_lockinfo,SPLNONE,DEFAULT);
	SLI("vm_swap.vs_lock", vm_swap_lockinfo, SPLNONE, DEFAULT);
	SLI("vm_swap_io_lock", vm_swap_io_lockinfo, SPLNONE, DEFAULT);
	SLI("vm_swap_space_lock", vm_swap_space_lockinfo, SPLNONE, DEFAULT);
	SLI("vm_anon_object.ao_rsslock", ao_rsslock_lockinfo, SPLNONE, DEFAULT);
	SLI("vm_control.vm_queue_lock", vm_queue_lockinfo, SPLNONE, DEFAULT);
	SLI("ppg_umc.umc_lock", ppg_umc_lockinfo, SPLNONE, DEFAULT);
	SLI("umc_lru_lock", umc_lru_lockinfo, SPLNONE, DEFAULT);
	SLI("ubc_clru_lock", ubc_clru_lockinfo, SPLNONE, DEFAULT);
	SLI("ubc_lru_lock", ubc_lru_lockinfo, SPLNONE, DEFAULT);
	SLI("ubc_pages_lock", ubc_pages_lockinfo, SPLNONE, DEFAULT);
	SLI("ubc_dirty_lock", ubc_dirty_lockinfo, SPLNONE, DEFAULT);
	SLI("u_seg_cache_lock", u_seg_cache_lockinfo, SPLNONE, DEFAULT);
	SLI("free_page_tables.fp_lock", fpt_lockinfo, SPLNONE, DEFAULT);
	SLI("vm_anon_object.ao_lbitslock", ao_lbitslock_lockinfo, SPLNONE, DEFAULT);
	SLI("vm_swap_hash.bk_lock", vm_swap_hash_lockinfo, SPLNONE, DEFAULT);
	SLI("binlog_selq_lock", binlog_selq_lockinfo, SPLNONE, DEFAULT);

#if STREAMS != 0 || TIMOD || SVVS || STRKINFO || STRIFNET || XTISO || DLB || DLPI || LDTTY || RPTTY || PCKT || LAT 
	SLI("modsw_lock", modsw_lockinfo, SPLNONE, DEFAULT);
	SLI("sth_pipestat.lock", stb_lockinfo, SPLNONE, DEFAULT);
	SLI("sad_lock", sad_lockinfo, SPLNONE, DEFAULT);
	SLI("muxid_lock", streams_muxid_lockinfo, SPLNONE, DEFAULT);
	SLI("iocblk_id_lock", iocblk_id_lockinfo, SPLNONE, DEFAULT);
	SLI("weldq_lock", weldq_lockinfo, SPLNONE, DEFAULT);
	SLI("bufc_lock",streams_bufc_lockinfo, SPLNONE, DEFAULT);
	SLI("active_qlock_lock", active_qlock_lockinfo, SPLNONE, DEFAULT);
	SLI("streams_open_lock", streams_open_lockinfo, SPLNONE, DEFAULT);
	SLI("sth_s.sth_ext_flags_lock", sth_ext_flags_lockinfo, SPLNONE, DEFAULT);
#endif	/* STREAMS || TIMOD || SVVS || STRKINFO || STRIFNET || XTISO || DLB || DLPI || LDTTY || RPTTY || PCKT || LAT */

#if UIPC > 0
	NLI("unp_misc_lock", unp_misc_li, SPLNONE, DEFAULT);
#endif

#if XTISO
	SLI("xtiso_lock", xtiso_lockinfo, SPLNONE, DEFAULT);
	SLI("xtisoc_lock", xtisoc_lockinfo, SPLNONE, DEFAULT);
#endif	/* XTISO */

#if LDTTY
	SLI("ldtty.t_intimeout_lock", tp_intimeout_lockinfo, SPLNONE, DEFAULT);
#endif

#if 0
#if RT_SEM
	SLI("real_time.p4bsem_lock", p4bsem_lockinfo, SPLNONE, DEFAULT);
#endif
#endif
#if	(DLB > 0)
	NLI("dlbq_list_head_slock", dlbq_list_sli, SPLNONE, DEFAULT);
#endif
#if RT_CSEM || RT_IPC
	SLI("real_time.p4csem_lock", p4csem_lockinfo, SPLNONE, DEFAULT);
#endif
#if MCNET > 0
        LI("mcnet_psend_lock", mcnet_psend_lockinfo, SPLNONE, DEFAULT);
#endif
#if RM > 0
	LI("rm_mgmt_locks", rm_mgmt_lockinfo, SPLNONE, DEFAULT);
	LI("rm_mgmt_tag_lock", rm_mgmt_tag_lockinfo, SPLNONE, DEFAULT);
	LI("rm_mgmt_bitmap_lock", rm_mgmt_bitmap_lockinfo, SPLNONE, DEFAULT);
	LI("rm_lock_statistics_lock", rm_lock_statistics_lockinfo, SPLNONE, DEFAULT);
	LI("rm_callback_lock", rm_callback_lockinfo, SPLNONE, DEFAULT);
#endif
#if CNX > 0
        LI("Cnx_node_down_lock", Cnx_node_down_lockinfo, SPLNONE, DEFAULT);
#endif /* CNX */
	ULI("cxalloc_lock ", cxalloc_lockinfo, SPLSOFTC, DEFAULT);
	ULI("rci_registry_lock", rci_registry_lockinfo, SPLSOFTC, DEFAULT);
	ULI("rci_event_lock", rci_event_lockinfo, SPLSOFTC, DEFAULT);
	ULI("error_event_lock", event_cntrl_li, SPLSOFTC, DEFAULT);

#if CNX > 0
	LI("_csb.lock", Cnx_csb_lockinfo, SPLSOFTC, DEFAULT);
#endif /* CNX */

#if DLPI
	NLI("dltimer_lock", dltimer_lockinfo, SPLSOFTC, DEFAULT);
#endif

#ifdef	ASE
	ULI("amlog",            amlog_lock_li,          SPLSOFTC, DEFAULT);
	ULI("amcntrl",          am_cntrl_lock_li,       SPLSOFTC, DEFAULT);
	ULI("amcntrl.hflink",   am_host_lk_li,          SPLSOFTC, DEFAULT);
	ULI("amcntrl.dflink",   am_device_lk_li,        SPLSOFTC, DEFAULT);
	ULI("ase_table",        ase_table_lock_li,      SPLSOFTC, DEFAULT);
#endif

#ifdef	DTM
	ULI("dtm_stack_lock",	dtm_stack_lockinfo,  SPLSOFTC, DEFAULT);
	ULI("dtm_control",	dtm_control_lockinfo, SPLNONE, DEFAULT);
#endif

#if ATM
        ULI("atm_cmm_mmi_list",atm_cmm_mmi_list_info, SPLIMP,DEFAULT);
#if ATMIP
        ULI("atm_arp_delevt_lock", atm_arp_delevt_lock_li, SPLSOFTC, DEFAULT);
#endif
#endif

	SLI("log_lock", log_lockinfo, SPL1, DEFAULT);
	SLI("lag_softc_lock", lag_softc_lockinfo, SPLIMP, DEFAULT);
	NLI("ifqueue.ifq_slock_splnet", ifqueue_splnet_li, SPLNET, DEFAULT);

	/*
	 * The following locks are provided for loadable drivers.
	 * They must be first in the simple SPLBIO section of locks.
	 */
	ULI("ldbl_low1_lock", ldbl_low1_li, SPLBIO, DEFAULT);
	ULI("ldbl_low2_lock", ldbl_low2_li, SPLBIO, DEFAULT);
	ULI("ldbl_low3_lock", ldbl_low3_li, SPLBIO, DEFAULT);
	ULI("ldbl_low4_lock", ldbl_low4_li, SPLBIO, DEFAULT);
	ULI("ldbl_low5_lock", ldbl_low5_li, SPLBIO, DEFAULT);
	ULI("ldbl_low6_lock", ldbl_low6_li, SPLBIO, DEFAULT);
	ULI("ldbl_low7_lock", ldbl_low7_li, SPLBIO, DEFAULT);
	ULI("ldbl_low8_lock", ldbl_low8_li, SPLBIO, DEFAULT);
	ULI("ldbl_low9_lock", ldbl_low9_li, SPLBIO, DEFAULT);
	ULI("ldbl_low10_lock", ldbl_low10_li, SPLBIO, DEFAULT);

#if DRD > 0
        ULI("drd_barrier_lock",    drd_barrier_lockinfo,  SPLBIO, DEFAULT);
        ULI("drd_iob_lock",        drd_iob_lockinfo,      SPLBIO, DEFAULT);
        ULI("drd_notify_lock",     drd_notify_lockinfo,   SPLBIO, DEFAULT);
        ULI("drd_disk_lock",       drd_disk_lockinfo,     SPLBIO, DEFAULT);
        ULI("drd_event_que_lock",  drd_event_que_lockinfo,SPLBIO, DEFAULT);
        ULI("drd_node_lock",       drd_node_lockinfo,     SPLBIO, DEFAULT);
        ULI("drd_hash_lock",       drd_hash_lockinfo,     SPLBIO, DEFAULT);
        ULI("drd_lidlist_lock",    drd_lidlist_lockinfo,  SPLBIO, DEFAULT);
        ULI("drd_iodone_lock",     drd_iodone_lockinfo,   SPLBIO, DEFAULT);
#endif /* DRD */
#if NSCSI > 0
	ULI("cam_pd_unit_table",cam_pd_unit_table_li,   SPLBIO, DEFAULT);
	ULI("cam_pd_device",    cam_pd_device_li,       SPLBIO, DEFAULT);
	ULI("cam_resp_que",     cam_resp_que_li,        SPLBIO, DEFAULT);
	ULI("cam_pd_rad_device3",cam_pd_rad_device3_li, SPLBIO, DEFAULT);
	ULI("cam_pd_device3",   cam_pd_device3_li,      SPLBIO, DEFAULT);
	ULI("ccmn_path_mon", 	ccmn_path_mon_li,	SPLBIO, DEFAULT);
	ULI("cam_disk",    	cam_dsk_lock_li,        SPLBIO, DEFAULT);
	ULI("cam_disk_recq",   	cam_recq_lock_li,       SPLBIO, DEFAULT);
        ULI("cam_disk_recq",    cam_recq_lock_li,       SPLBIO, DEFAULT);
	ULI("cam_c_ctrl",       cam_c_ctrl_li,          SPLBIO, DEFAULT);
	ULI("cam_c_qhead",      cam_c_qhead_li,         SPLBIO, DEFAULT);
	ULI("cam_c_edt",        cam_c_edt_li,           SPLBIO, DEFAULT);
	ULI("scsi_did",   	scsi_did_li,      	SPLNONE, DEFAULT);
	ULI("cam_ccmn_data_pool",cam_ccmn_data_pool_li, SPLBIO, DEFAULT);
	ULI("cam_d3_ctrl",      cam_d3_ctrl_li,         SPLBIO, DEFAULT);
	ULI("cam_x_qhead1",     cam_x_qhead1_li,        SPLBIO, DEFAULT);
	ULI("cam_x_qhead2",     cam_x_qhead2_li,        SPLBIO, DEFAULT);
	ULI("cam_x_qhead3",     cam_x_qhead3_li,        SPLBIO, DEFAULT);
	ULI("cam_x_qhead4",     cam_x_qhead4_li,        SPLBIO, DEFAULT);
	ULI("cam_x_pqhead1",    cam_x_pqhead1_li,       SPLBIO, DEFAULT);
	ULI("cam_x_pqhead2",    cam_x_pqhead2_li,       SPLBIO, DEFAULT);
	ULI("cam_x_pqhead3",    cam_x_pqhead3_li,       SPLBIO, DEFAULT);
	ULI("cam_x_pqhead4",    cam_x_pqhead4_li,       SPLBIO, DEFAULT);
	ULI("cam_x_ctrl",       cam_x_ctrl_li,          SPLNONE, DEFAULT);

/* scsi only for now, expand when the next user comes along */
	ULI("ddr_lock",		ddr_lockinfo,		SPLBIO, DEFAULT);
	ULI("ddr_dbase",	ddr_dbase_open_lkinfo,	SPLBIO, DEFAULT);
	ULI("ddr_scsidevs",	ddr_scsidevs_lockinfo,	SPLBIO, DEFAULT);
	ULI("dev_desc.lk",	cam_ddr_dev_desc_lkinfo, SPLBIO, DEFAULT);

	ULI("cam_reg",          cam_reg_li,             SPLBIO, DEFAULT);
	ULI("cam_softc",        cam_softc_li,           SPLBIO, DEFAULT);
	ULI("cam_reg",          cam_reg_li,             SPLBIO, DEFAULT);
	ULI("cam_cplt",         cam_cplt_li,            SPLBIO, DEFAULT);
	ULI("cam_sm",           cam_sm_li,              SPLBIO, DEFAULT);
#endif
#if NASC > 0 || NPSIOP > 0 || NAHA > 0 || NISP > 0
	ULI("cam_htm",          cam_htm_nexuslk_li,     SPLBIO, DEFAULT);
#endif

#define OBSOLETE
#ifndef OBSOLETE

#if NXZA > 0
	ULI("cam_xza_target",   cam_xza_target_li,      SPLBIO, DEFAULT);
#endif

#endif /* !OBSOLETE */

#if NPSIOP > 0
        ULI("cam_psiop_doneq",   cam_psiop_doneq_li,    SPLBIO, DEFAULT);
        ULI("cam_psh",           cam_psh_li,            SPLBIO, DEFAULT);
        ULI("cam_psiopq",        cam_psiopq_li,         SPLBIO, DEFAULT);
        ULI("cam_psiop_cfg",     cam_psiop_cfg_li,      SPLBIO, DEFAULT);
        ULI("cam_pfree_job",     cam_pfree_job_li,      SPLBIO, DEFAULT);
#endif
#if NAHA > 0
	ULI("cam_aha_softc",	 cam_aha_softc_li,	SPLBIO, DEFAULT);
	ULI("cam_aha_freeq",	 cam_aha_freeq_li,	SPLBIO, DEFAULT);
	ULI("cam_aha_activeq",	 cam_aha_activeq_li,	SPLBIO, DEFAULT);
#endif
#if NATA > 0
	ULI("cam_ata_softc",     cam_ata_li,            SPLBIO, DEFAULT);
#endif

#ifndef OBSOLETE

#if NTZA > 0 || NPZA > 0
	ULI("cam_spo_generic",	 cam_spo_genericlk_li,	SPLBIO, DEFAULT);
	ULI("cam_spo_resource",	 cam_spo_resourcelk_li,	SPLBIO, DEFAULT);
	ULI("cam_spo_nexus",	 cam_spo_nexuslk_li,	SPLBIO, DEFAULT);
	ULI("cam_spo_iowaitq",	 cam_spo_iowaitq_li,	SPLBIO, DEFAULT);
	ULI("cam_spo_dacq",	 cam_spo_dacqlk_li,	SPLBIO, DEFAULT);
	ULI("cam_spo_dafq",	 cam_spo_dafqlk_li,	SPLBIO, DEFAULT);
	ULI("cam_spo_adrq",	 cam_spo_adrqlk_li,	SPLBIO, DEFAULT);
	ULI("cam_spo_adfq",	 cam_spo_adfqlk_li,	SPLBIO, DEFAULT);
	ULI("cam_spo_debug",	 cam_spo_debugqlk_li,	SPLBIO, DEFAULT);
#endif /* NTZA > 0 || NPZA > 0 */

#endif /* !OBSOLETE */

#if NISP > 0 
	ULI("isp_abort",         cam_isp_abort_li,      SPLBIO, DEFAULT);
	ULI_DISABLE_HIERARCHY_CHECKING(cam_isp_abort_li);
	ULI("cam_isp",		 cam_isp_li,		SPLBIO, DEFAULT);
#endif /* NISP > 0 */

#if NUSB > 0
	ULI("usb_bus.lock", usb_bus_li, SPLBIO, DEFAULT);
	ULI("usb_hub.lock", usb_hub_li, SPLBIO, DEFAULT);
	ULI("usb_device.lock", usb_device_li, SPLBIO, DEFAULT);
	ULI("usb_interface.lock", usb_interface_li, SPLBIO, DEFAULT);
	ULI("usb_pipe.lock", usb_pipe_li, SPLBIO, DEFAULT);
	ULI("usb_request.lock", usb_request_li, SPLBIO, DEFAULT);
	ULI("usb_array.lock", usb_array_li, SPLBIO, DEFAULT);
#endif

#if NXCR > 0
	ULI("astro_re_table",	re_table_li,		SPLBIO, DEFAULT);
	ULI("astro_re_device",	re_device_li,		SPLBIO, DEFAULT);
	ULI("astro_xcr_softc",	xcr_softc_li,		SPLBIO, DEFAULT);
	ULI("astro_xcr_reg",	xcr_reg_li,		SPLBIO, DEFAULT);
	ULI("astro_xcr_cb",	xcr_cb_li,		SPLBIO, DEFAULT);
#endif
#if NSCSI > 0
	ULI("cam_async_event_q", cam_async_event_li,	SPLBIO, DEFAULT);
	ULI("cam_pool_ctrl",    cam_pool_ctrl_li,       SPLNONE, DEFAULT);
	ULI("cam_pool_queue",   cam_pool_queue_li,      SPLNONE, DEFAULT);
	ULI("cam_ccmn_tmo_que",	ccmn_delayed_call_li,	SPLBIO, DEFAULT);
	ULI("cam_free_ws_que",	cam_free_ws_li,		SPLBIO, DEFAULT);
#endif

#if NPNVRAM > 0
	ULI("pnvram_softc_lock", pnvram_li,             SPLBIO, DEFAULT);
#endif

#if NENVRAM > 0
	ULI("envram_softc_lock", envram_li,             SPLBIO, DEFAULT);
#endif

	ULI("mount.m_throttle_lock", mount_throttle_lockinfo, SPLBIO, DEFAULT);

#if RM > 0
        /*
         * MC interrupts (like all PCI interrupts on Alpha) can come in at 
         * SPLDEVLOW or SPLDEVHIGH.  We use SPLDEVLOW in this declaration 
         * to cover the case when they come in at SPLDEVLOW.
         *
         * These locks are placed after the CAM locks because MC interrupts
         * can interrupt code holding the cam_pool_ctrl and cam_pool_queue 
         * locks above which would cause a lock hierarchy violation.
         *
         * It would be nice if those two locks were grouped with the
         * rest of the SPLNONE locks, but that's not an option at this
         * point.
         */
	SLI("rm_eh_init_lock", rm_eh_init_lockinfo, SPLDEVLOW, DEFAULT);
	SLI("rm_error_lock", rm_error_lockinfo, SPLDEVLOW, DEFAULT);
	SLI("rm_init_state_lock", rm_init_state_lockinfo, SPLDEVLOW, DEFAULT);
	SLI("rm_thread_lock", rm_thread_lockinfo, SPLDEVLOW, DEFAULT);
	SLI("rm_error_shutting_down_state_lock", rm_error_shutting_down_state_lockinfo, SPLDEVLOW, DEFAULT);
	SLI("rm_object_map_trans_intr_lock",rm_object_map_trans_intr_lockinfo, SPLDEVLOW, DEFAULT);
	SLI("rm_object_map_dual_intr_lock",rm_object_map_dual_intr_lockinfo, SPLDEVLOW, DEFAULT);
	SLI("vm_rm_object_mappers_lock", vm_rm_object_mappers_lockinfo, SPLDEVLOW, DEFAULT);
	SLI("vm_rm_base_address_lock", vm_rm_base_address_lockinfo, SPLDEVLOW, DEFAULT);
#endif

#if MCNET > 0
        LI("mcnet_reflock", mcnet_reflockinfo, SPLDEVLOW, DEFAULT);
#endif
#if CCOMSUB > 0
        SLI("CComGlbSlock", CComGlbSlockInfo, SPLDEVLOW, DEFAULT);
        SLI("CComQueSlock", CComQueSlockInfo, SPLDEVLOW, DEFAULT);
#endif
#if RM > 0
	SLI("rm_event_buff_lock", rm_event_buff_lockinfo, SPLDEVLOW, DEFAULT);
#endif
#if	ICS_LL_MCT > 0
        SLI("ics_mct_llirail_lock",
                                ics_mct_llirail_lockinfo,   SPLDEVLOW, DEFAULT);
        SLI("ics_mct_llinput_lock",
                                ics_mct_llinput_lockinfo,   SPLDEVLOW, DEFAULT);
        SLI("ics_mct_llnodeinfo_lock",
                                ics_mct_llnodeinfo_lockinfo,SPLDEVLOW, DEFAULT);
#endif  /* ICS_LL_MCT */

/* locks for PPP - note that there's no SPLSTR, so we use SPLTTY which
 * for the moment is the same (see <sys/streams.h>).  Also, it happens
 * that SPLIMP and SPLTTY are the same (supposedly for the sake of
 * SLIP, SPLIMP must be >= SPLTTY - see <sys/machine/cpu.h>.)
 */
#if PPP > 0
	SLI("ppp_if_lock", ppp_if_lockinfo, SPLTTY, DEFAULT);
	SLI("ppp_ifnet_lock", ppp_ifnet_lockinfo, SPLIMP, DEFAULT);
	SLI("ppp_minor_dev_lock", ppp_minor_dev_lockinfo, SPLTTY, DEFAULT);
	SLI("ppp_ppa_lock", ppp_ppa_lockinfo, SPLTTY, DEFAULT);
	SLI("ppp_alloc_lock", ppp_alloc_lockinfo, SPLTTY, DEFAULT);
#endif /* PPP */

#if STREAMS != 0 || TIMOD || SVVS || STRKINFO || STRIFNET || XTISO || DLB || DLPI || LDTTY || RPTTY || PCKT || LAT 
	SLI("osrq_lock", osrq_lockinfo, SPLDEVHIGH,DEFAULT);
	SLI("streams_log_lock", streamsm_log_lockinfo, SPLDEVHIGH,DEFAULT);
	SLI("mblk_lock",streams_mblk_lockinfo, SPLDEVHIGH, DEFAULT);
	SLI("queue(streams).q_lock", streams_q_lockinfo, SPLDEVHIGH, DEFAULT);
	SLI("sqh_s.sqh_lock", sqh_lockinfo, SPLDEVHIGH, DEFAULT);
	SLI("str_to_lock", str_to_lockinfo, SPLDEVHIGH, DEFAULT);
	SLI("sqe_s.sq_flags_lock", sq_flags_lockinfo, SPLDEVHIGH, DEFAULT);
	SLI("p_strsigs_lock", p_strsigs_lockinfo, SPLDEVHIGH, DEFAULT);
#endif /* STREAMS != 0 || TIMOD || SVVS || STRKINFO || STRIFNET || XTISO || DLB || DLPI || LDTTY || RPTTY || PCKT || LAT */
#if	(DLB > 0)
	NLI("dlb_slock", dlb_sli, SPLIMP, DEFAULT);
	NLI("dlbq_lock", dlbq_sli, SPLIMP, DEFAULT);
#endif
#if MCNET > 0
        NLI("mcnet_sclock", mcnet_sclockinfo, SPLIMP, DEFAULT);
#endif
#if NGWSCREEN > 0
	NLI("gwscreen_lock", gwscreen_li, SPLIMP, DEFAULT);
#endif
#if ICSNET > 0
        /* ICSNET */
        SLI("icsnet_lock",	icsnet_lockinfo,	SPLIMP, DEFAULT);
	SLI("icsnet_member_lock", icsnet_member_lockinfo, SPLIMP, DEFAULT);
#endif
	/* TEGEC */
	SLI("te_softc.lk_te_softc", te_softc_lockinfo, SPLIMP, DEFAULT);
	/* TULIP */
	SLI("tu_softc.lk_tu_softc", tu_softc_lockinfo, SPLIMP, DEFAULT);
	/* DEMNA */
	SLI("xna_softc.lk_xna_softc", xna_softc_lockinfo, SPLIMP, DEFAULT);
	/* DEMFA */
	SLI("mfa_softc.lk_mfa_softc", mfa_softc_lockinfo, SPLIMP, DEFAULT);
	/* DEFTA, DEFEA, DEFPA */
	SLI("fta_softc.lk_fta_softc", fta_softc_lockinfo, SPLIMP, DEFAULT);
        SLI("fta_softc.lk_fta_xmit", fta_xmit_lockinfo, SPLIMP, DEFAULT);
        SLI("fta_softc.lk_fta_regs", fta_regs_lockinfo, SPLIMP, DEFAULT);
        /* DGLTA, DGLPB */
        SLI("otto_softc.lk_otto_softc", otto_softc_lockinfo, SPLIMP, DEFAULT);
        SLI("otto_softc.lk_ready_q", otto_rdy_q_lockinfo, SPLIMP, DEFAULT);
	/* FORE HE622 ATM driver */
	SLI("lfa_unit_lock", lfa_unit_lockinfo, SPLIMP, DEFAULT);
	SLI("lfa_rdy_q_lock", lfa_rdy_q_lockinfo, SPLIMP, DEFAULT);
	SLI("lfa_dma_pool_lock", lfa_dma_pool_lockinfo, SPLIMP, DEFAULT);
	SLI("lfa_tx_pool_lock", lfa_tx_pool_lockinfo, SPLIMP, DEFAULT);
	SLI("lfa_trg_lock", lfa_trg_lockinfo, SPLIMP, DEFAULT);
	SLI("lfa_trc_lock", lfa_trc_lockinfo, SPLIMP, DEFAULT);
	SLI("lfa_tpdrq_lock", lfa_tpdrq_lockinfo, SPLIMP, DEFAULT);
	SLI("lfa_rbpq_lock", lfa_rbpq_lockinfo, SPLIMP, DEFAULT);
	SLI("lfa_bvc_lock", lfa_bvc_lockinfo, SPLIMP, DEFAULT);
	SLI("lfa_timeout_lock", lfa_timeout_lockinfo, SPLIMP, DEFAULT);
	SLI("lfa_reg_lock", lfa_reg_lockinfo, SPLIMP, DEFAULT);
	NLI("ip4t_softc.ip4t_lk_softc", ip4t_lk_softc_li, SPLIMP, DEFAULT);
	NLI("tunif_softc.tunif_lk_softc", tunif_lk_softc_li, SPLIMP, DEFAULT);
#if PACKETFILTER > 0
	NLI("pfilt_lock", pfilt_lockinfo, SPLIMP, DEFAULT);
#endif
#if	defined(DEC2100_A500) || defined(DEC2100_C500)
	ULI("PCI0_hae0_3_lock",        PCI0_hae0_3_li, SPLDEVHIGH, DEFAULT);
	ULI("PCI1_hae0_3_lock",        PCI1_hae0_3_li, SPLDEVHIGH, DEFAULT);
	ULI("cbus2_pci_int_lock",      cbus2_pci_int_li, SPLDEVHIGH, DEFAULT);
#endif	/* defined(DEC2100_A500) || defined(DEC2100_C500) */
#ifdef	DEC21000
	ULI("pcia_ctl_lock",        pcia_ctl_li, SPLDEVHIGH, DEFAULT);
#endif	/* DEC21000	*/
#if NPCI > 0
#ifndef	__intel__
	ULI("dma_hw_sg_rmap_lock", sg_rmap_lockinfo, SPLDEVHIGH, DEFAULT);
#endif
	ULI("shared_intr_lock", intr_add, SPLDEVHIGH, DEFAULT);
	ULI("shared_intr_act_lock", intr_act, SPLDEVHIGH, DEFAULT);
#endif	/* NPCI	*/
#if PWRMGR_ENABLED
	ULI("pwrmgr_data_lock", pwrmgr_lock_info, SPLDEVHIGH, DEFAULT);
#endif
	NLI("ifqueue.ifq_slock", ifqueue_li, SPLIMP, ORDERED);
	NLI("ifnet.if_slock", ifnet_li, SPLIMP, DEFAULT);
	NLI("mbuf_ext_slock", mbuf_ext_sli, SPLIMP, DEFAULT);
	NLI("mbuf_slock", mbuf_sli, SPLIMP, DEFAULT);
	ULI("cku_private.lk_outbuf", cku_lk_outbuf_info, SPLIMP, DEFAULT);
	ULI("udp_data.lk_udpdata", lk_udpdata_info, SPLIMP, DEFAULT);
	ULI("nfs_rrok_lock", nfs_rrok_lockinfo, SPLIMP, DEFAULT);
	ULI("nfs_xprtfree_lock", nfs_xprtfree_lockinfo, SPLIMP, DEFAULT);
	NLI("netisr_slock", netisr_li, SPLIMP, DEFAULT);
	NLI("aio_socket_lock", aio_socket_lockinfo, SPLIMP, DEFAULT);
	NLI("niff_event_q_lock",niff_event_q_lock_li,SPLIMP, DEFAULT);

        /* ATM LOCKS */
#if ATM
#if ATMIP
        ULI("atmip_driver_q_lock",atmip_driver_q_li,SPLIMP, DEFAULT);
        ULI("atmip_zombie_vc_lock",atmip_vc_zombie_li,SPLIMP, DEFAULT);
        ULI("atmip_zombie_ppa_lock",atmip_ppa_zombie_li,SPLIMP, DEFAULT);
        ULI("atmip_rtupdt_lock",atmip_rtupdt_li,SPLIMP, DEFAULT);
        ULI("atmip_drv_ppaq_lock",atmip_drv_ppaq_li,SPLIMP, DEFAULT);
        ULI("atmip_drv_esiq_lock",atmip_drv_esiq_li,SPLIMP, DEFAULT);
        ULI("atmip_drv_ifq_lock",atmip_drv_ifq_li,SPLIMP, DEFAULT);
        ULI("atmip_esi_ifq_lock",atmip_esi_ifq_li,SPLIMP, DEFAULT);
        ULI("atmip_map_lock",atmip_map_li,SPLIMP, DEFAULT);
        ULI("atmip_map_sec_lock",atmip_map_sec_li,SPLIMP, DEFAULT);
        ULI("atmip_ppa_lock", atmip_ppa_li, SPLIMP, DEFAULT);
        ULI("atm_arp_rcv_q_lock", atm_arp_rcv_q_lock_li, SPLIMP, DEFAULT);
        ULI("atm_arp_table_lock", atm_arp_table_lock_li, SPLIMP, DEFAULT);
        ULI("atm_arp_bucket_lock", atm_arp_bucket_lock_li, SPLIMP, DEFAULT);
        ULI("atm_arp_data_lock", atm_arp_data_lock_li, SPLIMP, DEFAULT);
        ULI("atmip_vc_lock", atmip_vc_li, SPLIMP, DEFAULT);
        ULI("atmip_ifnet_lock", atmip_ifnet_li, SPLIMP, DEFAULT);
        ULI("inarp_pending_q_lock", inarp_pending_q_lock_li, SPLIMP, DEFAULT);
#endif
#if LANE
        ULI("atmlane_elan_softc_lock",atmlane_elan_softc_li,SPLIMP,DEFAULT);

        ULI("atmlane_cm_instance_lock",atmlane_cm_instance_li,SPLIMP,DEFAULT);
        ULI("atmlane_cm_instance.sap_list",atmlane_sap_list_li,SPLIMP,DEFAULT);
        ULI("atmlane_cm_instance.availppas_list",atmlane_availppas_list_li,SPLIMP,DEFAULT);
        ULI("atmlane_cm_instance.sap_zombie_list",atmlane_sap_zombie_list_li,SPLIMP,DEFAULT);
        ULI("atmlane_cm_instance.vc_zombie_list",atmlane_vc_zombie_list_li,SPLIMP,DEFAULT);

        ULI("atmlane_sap_lock",atmlane_sap_li,SPLIMP,DEFAULT);
        ULI("atmlane_sap.vc_list",atmlane_vc_list_li,SPLIMP,DEFAULT);
        ULI("atmlane_sap.atm_list",atmlane_atm_list_li,SPLIMP,DEFAULT);
        ULI("atmlane_sap.vc_rcvq_list",atmlane_vc_rcvq_list_li,SPLIMP,DEFAULT);

        ULI("atmlane_ppa_lock",atmlane_ppa_li,SPLIMP,DEFAULT);
        ULI("atmlane_vc_lock",atmlane_vc_li,SPLIMP,DEFAULT);

        ULI("atmlane_atmrec_lock",atmlane_atmrec_li,SPLIMP,DEFAULT);
        ULI("atmlane_atmrec.vc_link_list",atmlane_vc_link_list_li,SPLIMP,DEFAULT);
        ULI("atmlane_atmrec.vc_update_list",atmlane_vc_update_list_li,SPLIMP,DEFAULT);
        ULI("atmlane_atmrec.esi_link_list",atmlane_esi_link_list_li,SPLIMP,DEFAULT);
        ULI("atmlane_atmrec.esi_update_list",atmlane_esi_update_list_li,SPLIMP,DEFAULT);

        ULI("atmlane_la_elan_lock",atmlane_la_elan_li,SPLIMP,DEFAULT);
        ULI("atmlane_la_elan.esi_list",atmlane_esi_list_li,SPLIMP,DEFAULT);
        ULI("atmlane_esi_lock",atmlane_esi_li,SPLIMP,DEFAULT);
        ULI("atmlane_eventqueue_lock",atmlane_eventqueue_li,SPLIMP,DEFAULT);

        ULI("atmlane_lc_context_lock",atmlane_lc_context_li,SPLIMP,DEFAULT);
        ULI("atmlane_lc_context.elan_list",atmlane_lc_elan_list_li,SPLIMP,DEFAULT);
        ULI("atmlane_lc_elan_lock",atmlane_lc_elan_li,SPLIMP,DEFAULT);
        ULI("atmlane_lc_elan.regmac_list",atmlane_reg_mac_list_li,SPLIMP,DEFAULT);

        ULI("atmlane_ld_context_lock",atmlane_ld_context_li,SPLIMP,DEFAULT);
        ULI("atmlane_ld_context.elan_list",atmlane_ld_elan_list_li,SPLIMP,DEFAULT);
        ULI("atmlane_ld_elan_lock",atmlane_ld_elan_li,SPLIMP,DEFAULT);
        ULI("atmlane_ld_elan.mcast_list",atmlane_mcast_list_li,SPLIMP,DEFAULT);
        ULI("atmlane_mcast_entry_lock",atmlane_mcast_entry_li,SPLIMP,DEFAULT);

        ULI("atmlane_osinfo.timer_list", atmlane_timer_list_li,SPLIMP,DEFAULT);
        ULI("atmlane_timer_lock",atmlane_timer_li,SPLIMP,DEFAULT);
#endif
#if PAT /* ATM Test package */
	ULI("pat(sess)->updown_lock", pat_updown_lock_i, SPLIMP, DEFAULT);
	ULI("pat_softc.sessvec_lock", pat_sessvec_lock_i, SPLIMP, DEFAULT);
	ULI("pat(sess)->downup_lock", pat_downup_lock_i, SPLIMP, DEFAULT);
	ULI("pat_softc.bindq_lock", pat_bindq_lock_i, SPLIMP, DEFAULT);
	ULI("pat(ppa)->lock", pat_ppa_lock_i, SPLIMP, DEFAULT);
	ULI("pat_softc.ticket_lock", pat_ticket_lock_i, SPLIMP, DEFAULT);
	ULI("pat_softc.waitid_lock", pat_waitid_lock_i, SPLIMP, DEFAULT);
	ULI("pat_softc.exit_hand_lock", pat_exit_hand_lock_i, SPLIMP, DEFAULT);
#endif
#if ATMUNI
	ULI("atmuni_softc.drv_lock", atmuni_drv_lock_i, SPLIMP, DEFAULT);
	ULI("atmuni_softc.vuni_lock", atmuni_vuni_lock_i,
	                                    SPLIMP, DEFAULT);
	ULI("atmuni_softc.vuni_prv_lock(uni)",
	                 atmuni_vuni_prv_lock_i,
	                 SPLIMP, DEFAULT);
	ULI("atmuni_softc.ilmi_lock", atmuni_ilmi_lock_i,
	                 SPLIMP, DEFAULT);
	ULI("atmuni_softc.sig_lock", atmuni_sig_lock_i,
	                 SPLIMP, DEFAULT);
	ULI("atmuni_softc.unigen_lock", atmuni_unigen_lock_i,
	                 SPLIMP, DEFAULT);
#endif
        ULI("atm_cmm_driver_list",atm_cmm_driver_list_info,SPLIMP,DEFAULT);
        ULI("atm_cmm_ppa_list",atm_cmm_ppa_list_info,SPLIMP,DEFAULT);
        ULI("atm_cmm_converge_list",atm_cmm_converge_list_info,SPLIMP,DEFAULT);
        ULI("atm_cmm_signal_list",atm_cmm_signal_list_info,SPLIMP,DEFAULT);
        ULI("atm_cmm_vc_zombies_list",atm_cmm_vc_zombies_list_info,
                                        SPLIMP,DEFAULT);
        ULI("atm_cmm_vcs_zombies_list",atm_cmm_vcs_zombies_list_info,
                                        SPLIMP,DEFAULT);
        ULI("atm_cmm_bind_zombies_list",atm_cmm_bind_zombies_list_info,
                                        SPLIMP,DEFAULT);
        ULI("atm_cmm_ppa_zombies_list",atm_cmm_ppa_zombies_list_info,
                                        SPLIMP,DEFAULT);
        ULI("atm_cmm_addr_zombies_list",atm_cmm_addr_zombies_list_info,
                                        SPLIMP,DEFAULT);

        ULI("atm_cmm_device_lock",atm_cmm_device_lock_info,SPLIMP,DEFAULT);
	ULI("atm_time_aging_vcs_list",atm_cmm_vc_time_aging_info,
					SPLIMP,DEFAULT);
        ULI("atm_cmm_device.esi_list",atm_cmm_device_esi_list_lock_info,
                                        SPLIMP,DEFAULT);
        ULI("atm_cmm_device.ppas_list",atm_cmm_device_ppas_list_lock_info,
                                        SPLIMP,DEFAULT);
        ULI("atm_cmm_device.vchash_list",atm_cmm_device_vchash_list_lock_info,
                                        SPLIMP,DEFAULT);
        ULI("atm_cmm_device.vcs_list",atm_cmm_device_vcs_list_lock_info,
                                        SPLIMP,DEFAULT);
        ULI("atm_cmm_device.unalloc_list",atm_cmm_device_unalloc_list_lock_info,
                                        SPLIMP,DEFAULT);
        ULI("atm_cmm_device.unused_list",atm_cmm_device_unused_list_lock_info,
                                        SPLIMP,DEFAULT);
        ULI("atm_cmm_res_exp_list",atm_cmm_res_exp_list_info, SPLIMP,DEFAULT);

        ULI("atm_cmm_esi_lock",atm_cmm_esi_lock_info,SPLIMP,DEFAULT);

        ULI("atm_cmm_ppa_lock",atm_cmm_ppa_lock_info,SPLIMP,DEFAULT);
        ULI("atm_cmm_ppa_lock.binds_list",atm_cmm_ppa_binds_list_lock_info,
                                        SPLIMP,DEFAULT);
        ULI("atm_cmm_ppa_lock.dbinds_list",atm_cmm_ppa_dbinds_list_lock_info,
                                        SPLIMP,DEFAULT);


        ULI("atm_cmm_cvg_lock",atm_cmm_cvg_lock_info,SPLIMP,DEFAULT);
        ULI("atm_cmm_cvg.esis_list",atm_cmm_cvg_esis_list_lock_info,
                                        SPLIMP,DEFAULT);
        ULI("atm_cmm_cvg.binds_list",atm_cmm_cvg_binds_list_lock_info,
                                        SPLIMP,DEFAULT);
        ULI("atm_cmm_cvg.vcs_list",atm_cmm_cvg_vcs_list_lock_info,
                                        SPLIMP,DEFAULT);

        ULI("atm_cmm_sig_lock",atm_cmm_sig_lock_info,SPLIMP,DEFAULT);
        ULI("atm_cmm_sig.ppas_list",atm_cmm_sig_ppas_list_lock_info,
                                        SPLIMP,DEFAULT);
        ULI("atm_cmm_sig_lock.vcs_list",atm_cmm_sig_vcs_list_lock_info,
                                        SPLIMP,DEFAULT);

        ULI("atm_cmm_bind_lock",atm_cmm_bind_lock_info,SPLIMP,DEFAULT);
        ULI("atm_cmm_bind.vcs_list",atm_cmm_bind_vcs_list_lock_info,
                                        SPLIMP,DEFAULT);
	ULI("atm_cmm_start_queue",atm_cmm_start_q_list_lock_info,
					SPLIMP,DEFAULT);
        ULI("atm_cmm_vc_lock",atm_cmm_vc_lock_info,SPLIMP,DEFAULT);
        ULI("atm_cmm_vc.eps_list",atm_cmm_vc_eps_list_lock_info,
                                        SPLIMP,DEFAULT);
        ULI("atm_cmm_vc.ieps_list",atm_cmm_vc_ieps_list_lock_info,
                                        SPLIMP,DEFAULT);
        ULI("atm_cmm_vc.ceps_list",atm_cmm_vc_ceps_list_lock_info,
                                        SPLIMP,DEFAULT);
        ULI("atm_cmm_vc.deps_list",atm_cmm_vc_deps_list_lock_info,
                                        SPLIMP,DEFAULT);
        ULI("atm_cmm_vc.neps_list",atm_cmm_vc_neps_list_lock_info,
                                        SPLIMP,DEFAULT);
        ULI("atm_cmm_vc.causes_list",atm_cmm_vc_causes_list_lock_info,
                                        SPLIMP,DEFAULT);
        ULI("atm_cmm_vc.log_list",atm_cmm_vc_log_list_lock_info,
                                        SPLIMP,DEFAULT);
        ULI("atm_cmm_addr_lock",atm_cmm_addr_lock_info,SPLIMP,DEFAULT);

        ULI("atm_cmm_vcs_lock",atm_cmm_vcs_lock_info,SPLIMP,DEFAULT);
#if ATMSIG2 /* Second ATM signaling module */
	ULI("atmsig2_softc.lock", atmsig2_lock_i, SPLIMP, DEFAULT);
	ULI("atmsig2_softc.rq_lock", atmsig2_rq_lock_i, SPLIMP, DEFAULT);
	ULI("atmsig2_softc.rx_lock", atmsig2_rx_lock_i, SPLIMP, DEFAULT);
#endif
#if ATMILMI3X /* ATM ILMI */
	ULI("atm:ilmi_softc.lock", ilmi_lock_i, SPLIMP, DEFAULT);
	ULI("atm:ilmi_softc.rq_lock(ctx)", ilmi_rq_lock_i, SPLIMP, DEFAULT);
	ULI("atm:ilmi_softc.rx_lock(ctx)", ilmi_rx_lock_i, SPLIMP, DEFAULT);
#endif
#if UNI3X /* New ATM Signaling */
	ULI("atmsig_softc.rq_lock", atmsig_rq_lock_i, SPLIMP, DEFAULT);
	ULI("atmsig_softc.rx_lock", atmsig_rx_lock_i, SPLIMP, DEFAULT);
	NLI("atmsig_softc.trace_lock(ctx)", atmsig_trace_lock_i, SPLNONE, DEFAULT);
	ULI("atmsig_softc.callref_lock(ctx)", atmsig_callref_lock_i, SPLIMP, DEFAULT);
	ULI("atmsig_softc.lock", atmsig_lock_i, SPLIMP, DEFAULT);
#endif
#if PAT /* ATM Test package */
	ULI("pat(sess)->downup_lock", pat_downup_lock_i, SPLIMP, DEFAULT);
#endif
#if ATMIFMP /* IP Switching */
        ULI("atmifmp_rcv_q_lock",atmifmp_rcv_q_li,SPLIMP, DEFAULT);
        ULI("atmifmp_pvcppa_q_lock",atmifmp_pvcppa_q_li,SPLIMP, DEFAULT);
        ULI("atmifmp_pvcppa.atmifmp_pvcppa_lock",atmifmp_pvcppa_li,SPLIMP, DEFAULT);
        ULI("atmifmp_ifnet.oslock.atmifmp_ipshost_lock",atmifmp_ipshost_li,SPLIMP, DEFAULT);
        ULI("atmifmp_pvc.atmifmp_pvc_lock",atmifmp_pvc_li,SPLIMP, DEFAULT);
        ULI("atmifmp_ifnet.atmifmp_ifnet_lock",atmifmp_ifnet_li,SPLIMP, DEFAULT);
#endif
#if ATMTM  /* Another ATM Test Module (atmtm) */
	ULI("atmtm_ppa_qlock", atmtm_ppa_qlkinfo, SPLIMP, DEFAULT);
	ULI("atmtm_vc_lock", atmtm_vc_lkinfo, SPLIMP, DEFAULT);
	ULI("atmtm_concon_qlock", atmtm_concon_qlkinfo, SPLIMP, DEFAULT);
	ULI("atmtm_report_qlock", atmtm_report_qlkinfo, SPLIMP, DEFAULT);
	ULI("atmtm_con_handle_lock", atmtm_con_handle_lkinfo, SPLIMP, DEFAULT);
	ULI("atmtm_srv_handle_lock", atmtm_srv_handle_lkinfo, SPLIMP, DEFAULT);
	ULI("atmtm_repfree_qlock", atmtm_repfree_qlkinfo, SPLIMP, DEFAULT);
	ULI("atmtm_misc_lock", atmtm_misc_lkinfo, SPLIMP, DEFAULT);
#endif
#endif
        /* End of ATM locks */

#if IPSEC
	ULI("plaintext_rpc_list_lock", plaintext_rpc_list_lockinfo, SPLIMP, DEFAULT);
#endif
	/*
	 * The following locks are provided for loadable drivers.
	 * They must be last in the simple SPLBIO section of locks.
	 */
	ULI("ldbl_hi1_lock", ldbl_hi1_li, SPLBIO, DEFAULT);
	ULI("ldbl_hi2_lock", ldbl_hi2_li, SPLBIO, DEFAULT);
	ULI("ldbl_hi3_lock", ldbl_hi3_li, SPLBIO, DEFAULT);
	ULI("ldbl_hi4_lock", ldbl_hi4_li, SPLBIO, DEFAULT);
	ULI("ldbl_hi5_lock", ldbl_hi5_li, SPLBIO, DEFAULT);
	ULI("ldbl_hi6_lock", ldbl_hi6_li, SPLBIO, DEFAULT);
	ULI("ldbl_hi7_lock", ldbl_hi7_li, SPLBIO, DEFAULT);
	ULI("ldbl_hi8_lock", ldbl_hi8_li, SPLBIO, DEFAULT);
	ULI("ldbl_hi9_lock", ldbl_hi9_li, SPLBIO, DEFAULT);
	ULI("ldbl_hi10_lock", ldbl_hi10_li, SPLBIO, DEFAULT);

	SLI("text_replication_lock", text_replication_lockinfo, SPLDEVHIGH, DEFAULT);
	SLI("vm_page_pvh.lock", vm_page_pvh_lockinfo, SPLIMP, DEFAULT);
	SLI("pmap_seg.ps_seg_lock", pmap_seg_ps_seglockinfo, SPLIMP, DEFAULT);
	SLI("pmap_ssm.pss_lock", pmap_ssm_lockinfo, SPLIMP, DEFAULT);
	SLI("pmap.lock", user_pmap_lockinfo, SPLIMP, DEFAULT);
	SLI("pmap.other_lock", user_pmap_other_lockinfo, SPLIMP, DEFAULT);
	SLI("kernel_pmap.lock", kernel_pmap_lockinfo, SPLIMP, DEFAULT);
	SLI("kernel_pmap.other_lock", kernel_pmap_other_lockinfo,
							SPLIMP, DEFAULT);
	SLI("reaper_lock", reaper_lockinfo, SPLSCHED, DEFAULT);
#ifdef TNC_ICS
	SLI("tcrevent.tev_slock", tcrevent_lockinfo, SPLHIGH, DEFAULT);
#endif
	SLI("thread_callq.tcq_lock", tcq_lockinfo, SPLHIGH, DEFAULT);
	SLI("mpqueue_head.lock", mpqueue_lockinfo, SPLHIGH, DEFAULT);
	SLI("kmemdata.waitlock", kmemdata_waitlock_info, SPLHIGH, DEFAULT);
	SLI("malloc_control.m_lock", mcntl_lockinfo, SPLHIGH, DEFAULT);
	SLI("kmembuckets.kb_lock", kdp_kb_lockinfo, SPLHIGH, DEFAULT);
	SLI("vm_control.vm_free_lock", vm_free_lockinfo, SPLHIGH, DEFAULT);
	SLI("kmem_debug_lock", kmem_debug_lockinfo, SPLHIGH, DEFAULT);
	SLI("vm_page_bucket.bk_lock", vm_page_bucket_lockinfo, SPLHIGH,DEFAULT);
	SLI("contig_malloc_lock", contig_malloc_lockinfo, SPLHIGH, DEFAULT);
	SLI("pmap_memdsc_lock", pmap_memdsc_lockinfo, SPLHIGH, DEFAULT);
#if CRYPTO
	/* crypto callback lock -- low so other subsystems can call crypto */
	LI("kcrypto_lock", kcrypto_lock_info, SPLNONE, DEFAULT);
#endif

	/* lock classes below here cannot use assert_wait, wakeup, etc. */

	SLI("class.lock", class_lockinfo, SPLSCHED, DEFAULT);
	SLI("thread.lock", thread_lockinfo, SPLSCHED, ORDERED);
	SLI("event.ev_slock", event_lockinfo, SPLSCHED, DEFAULT);
	SLI("wait_queue.lock", wait_queue_lockinfo, SPLSCHED, DEFAULT);
	SLI("swap_control.sc_t_qlock", thread_swap_lockinfo, SPLSCHED, DEFAULT);
	SLI("pag.idle_lock", pag_idle_lockinfo, SPLSCHED, DEFAULT);
	SLI("processor.lock", processor_lockinfo, SPLSCHED, DEFAULT);
	SLI("processor.runq.lock", proc_runq_lockinfo, SPLSCHED, DEFAULT);
	SLI("pag.runq.lock", pag_runq_lockinfo, SPLSCHED, DEFAULT);
	SLI("action_lock", action_lockinfo, SPLSCHED, DEFAULT);

	ULI("session.s_fpgrp_lock", sess_fpgrp_lockinfo, SPLHIGH, DEFAULT);
	ULI("pgrp.pg_ref_lock", pgrp_refcnt_lockinfo, SPLHIGH, DEFAULT);
	SLI("xprlock", xprlockinfo, SPLHIGH, DEFAULT);


	SLI("callout_lock", callout_lockinfo, SPLCLOCK, DEFAULT);
	ULI("proc.p_timer_lock", proc_timer_lockinfo, SPLCLOCK, DEFAULT);

	SLI("processor.callout_lock", processor_callout_lockinfo, SPLDEVRT, ORDERED);
	SLI("callout_free_lock", callout_free_lockinfo, SPLDEVRT, DEFAULT);

	SLI("binlog_lock", binlog_lockinfo, SPLEXTREME, DEFAULT);
	SLI("msgbuf_lock", msgbuf_lockinfo, SPLEXTREME, DEFAULT);
	SLI("tsd_table_lock", tsd_table_lockinfo, SPLNONE, DEFAULT);

	/******************************************/
	/* end of lockinfo specs for simple locks */
	/******************************************/

	/****************************************************/
	/* start of lockinfo specs for NOCHECK simple locks */
	/****************************************************/

#if	(DEC4000 == 1)
	ULI_NOCHECK("kn430_fprint_lock", kn430_fprint_lockinfo);
	ULI_NOCHECK("kn430_watch_lock", kn430_watch_lockinfo);
#endif	/* DEC4000 */
	/* NTRA */
	ULI_NOCHECK("tra_softc.scb_clear_lock",  tra_lockinfo);
	ULI_NOCHECK("bp_map.map_lock", bp_map_lockinfo);
	ULI_NOCHECK("cluster_bl_lock", cluster_bl_lockinfo);
	ULI_NOCHECK("exec_switch_lock", exec_switch_lockinfo);
#if	(CDFS > 0)
	ULI_NOCHECK("cdfs.lock", cdfs_lockinfo);
	ULI_NOCHECK("cdhead.hash_lock", cdfs_hash_lockinfo);
	ULI_NOCHECK("cdfs.mount_lock", cdfsmount_lockinfo);
	ULI_NOCHECK("cnode.cd_incore_lock", cdfs_incore_lockinfo);
#endif	/* CDFS > 0 */
#if	(FFM_FS > 0)
	ULI_NOCHECK("ffm_mounttab_lock", ffm_mounttab_lockinfo);
#endif	/* FFM_FS > 0 */
#if	(NPSIOP > 0)
	ULI_NOCHECK("siop_lock", siop_lockinfo);
#endif	/* NPSIOP > 0 */
#if	(VAGUE_STATS == 0)
	ULI_NOCHECK("rpc_cl_stat_lock", rpc_cl_stat_lockinfo);
	ULI_NOCHECK("rpc_sv_stat_lock", rpc_sv_stat_lockinfo);
#endif
#if	(NVBA > 0) || (CVBA > 0)
	ULI_NOCHECK("vba_bus_adapt.adapt_s_lock", vhp_adapt_s_lockinfo);
#endif	/* NVBA > 0 || CVBA > 0 */
#if	(STRIFNET > 0)
	ULI_NOCHECK("contextPtr.context_lock", streamsm_context_lockinfo);
	ULI_NOCHECK("list(streams)_lock", streamsm_list_lockinfo);
#endif	/* STRIFNET > 0 */
#if	(NLSM_TED > 0)
	ULI_NOCHECK("ted_lockp", ted_lockp_lockinfo);
	ULI_NOCHECK("ted_event.e_condp", ted_act_lockinfo);
#endif	/* NLSM_TED > 0 */
	ULI_NOCHECK("mfs_minor_lock", mfs_minor_lockinfo);
	ULI_NOCHECK("gen_lock", gen_lockinfo);
	ULI_NOCHECK("dqfree_lock", dqfree_lockinfo);
	ULI_NOCHECK("ump_qsync_lock", ump_qsync_lockinfo);
        ULI_NOCHECK("mounttab_lock", mounttab_lockinfo);
	ULI_NOCHECK("fs.fs_lock", fs_lockinfo);
	ULI_NOCHECK("fifo_fileid_lock", fifo_fileid_lockinfo);
	ULI_NOCHECK("fifonode.fn_fifo_lock", fifo_lockinfo);
	ULI_NOCHECK("speclisth.sh_lock", spechash_lockinfo);
	ULI_NOCHECK("devlist.lock",devlist_lockinfo);
	ULI_NOCHECK("bfreelist_lock", bfreelist_lockinfo);
	ULI_NOCHECK("bufhd.bhd_lock", bhash_lockinfo);
	ULI_NOCHECK("flckinfo.flckinfo_lock", flckinfo_lockinfo);
	ULI_NOCHECK("flino.flino_lock", flino_lockinfo);
	ULI_NOCHECK("fids_lock", fids_lockinfo);
	ULI_NOCHECK("vn_dealloc_cache_lockup_ref",
		    vn_dealloc_cache_lookup_ref_lockinfo);
	ULI_NOCHECK("mount.m_lock", mount_lockinfo);
	ULI_NOCHECK("mount.m_vlist_lock", mount_vlist_lockinfo);
	ULI_NOCHECK("vnode.v_output_lock", vnode_output_lockinfo);
	ULI_NOCHECK("vnode.v_buflists_lock", buflists_lockinfo);
	ULI_NOCHECK("mountlist_lock", mountlist_lockinfo);
#if	MACH_LDEBUG
	ULI_NOCHECK("vnode_trace_lock", vnode_trace_lockinfo);
#endif	/* MACH_LDEBUG */
#if	(MACH_XP_FPD > 0)
	ULI_NOCHECK("memory_manager_default_lock", 
		    memory_manager_default_lockinfo);
#endif	/* (MACH_XP_FPD > 0) */
	ULI_NOCHECK("vm_swap_list.vsl_lock", vm_swap_list_vsl_lockinfo);
#if	(NLSM > 0)
	ULI_NOCHECK("volspin.vol_alloc_spin_lock", vol_alloc_spin_lockinfo);
	ULI_NOCHECK("volsync.sy_lock", vol_allocsync_lockinfo);
	ULI_NOCHECK("clsm_state.st_lock", clsm_state_st_lockinfo);
#endif	/* NLSM	> 0) */
	ULI_NOCHECK("kevm_lock", kevm_lockinfo);
	ULI_NOCHECK("kevm_selq_lock", kevm_selq_lockinfo);
	ULI_NOCHECK("kevm_int_buf_lock", kevm_int_buf_lockinfo);
#ifdef	DTM
	ULI_NOCHECK("dtm_list_lock", dtm_list_lockinfo);
#endif

	/**************************************************/
	/* end of lockinfo specs for NOCHECK simple locks */
	/**************************************************/

	i = sizeof(long) - 1;
	lockstats_table = (struct lockstats **)(((unsigned long)lip + i) & ~i);
	i = (1 << LOCKSTATS_SHIFT) - 1;
	lsp = (struct lockstats *)
		(((unsigned long)(lockstats_table + cpu_slots) + i) & ~i);
	lockinfo_count = lip - lip_start;
	lockinfo_table = lip_start;

	if (lockmode == 4) {
		struct lockstats *p = lsp;

		for (i = 0; i < cpu_slots; i++, p += lockinfo_count)
			;
		bzero((char *)lip, (char *)p - (char *)lip);
		for (i = 0; i < cpu_slots; i++, lsp += lockinfo_count)
			lockstats_table[i] = lsp;
	} else {
		for (i = 0; i < cpu_slots; i++)
			lockstats_table[i] = NULL;
	}
	return((char *)lsp - (char *)lip_start);
}

/*
 * RT_PREEMPT_OPT is set at config time so that preemption can be
 * turned off in a kernel which has RT_PREEMPT compiled on.
 */
#if (RT_PREEMPT && defined(RT_PREEMPT_OPT))
long	rt_preempt_opt = 1; /* preemption is enabled */
#else
long	rt_preempt_opt = 0; /* preemption is disabled */
#endif

